@@ -362,9 +362,7 @@ void UpdateChecker::unpackUpdate() {
 
 	quint32 version;
 	{
-		QBuffer buffer(&uncompressed);
-		buffer.open(QIODevice::ReadOnly);
-		QDataStream stream(&buffer);
+		QDataStream stream(uncompressed);
 		stream.setVersion(QDataStream::Qt_5_1);
 
 		stream >> version;
@@ -488,7 +486,7 @@ UpdateChecker::~UpdateChecker() {
 
 bool checkReadyUpdate() {
 	QString readyFilePath = cWorkingDir() + qsl("tupdates/temp/ready"), readyPath = cWorkingDir() + qsl("tupdates/temp");
-	if (!QFile(readyFilePath).exists()) {
+	if (!QFile(readyFilePath).exists() || cExeName().isEmpty()) {
 		if (QDir(cWorkingDir() + qsl("tupdates/ready")).exists() || QDir(cWorkingDir() + qsl("tupdates/temp")).exists()) {
 			UpdateChecker::clearAll();
 		}
