@@ -21,6 +21,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "boxes/abstract_box.h"
 
 #include "styles/style_boxes.h"
+#include "styles/style_profile.h"
 #include "storage/localstorage.h"
 #include "lang/lang_keys.h"
 #include "ui/effects/widget_fade_wrap.h"
@@ -30,9 +31,6 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "mainwidget.h"
 #include "mainwindow.h"
 
-BoxLayerTitleShadow::BoxLayerTitleShadow(QWidget *parent) : Ui::PlainShadow(parent, st::boxLayerTitleShadow) {
-}
-
 QPointer<Ui::RoundButton> BoxContent::addButton(base::lambda<QString()> textFactory, base::lambda<void()> clickCallback) {
 	return addButton(std::move(textFactory), std::move(clickCallback), st::defaultBoxButton);
 }
@@ -244,7 +242,8 @@ void AbstractBox::paintEvent(QPaintEvent *e) {
 	auto paintTopRounded = clip.intersects(QRect(0, 0, width(), st::boxRadius));
 	auto paintBottomRounded = clip.intersects(QRect(0, height() - st::boxRadius, width(), st::boxRadius));
 	if (paintTopRounded || paintBottomRounded) {
-		auto parts = qFlags(RectPart::None);
+		auto parts = RectPart::None | 0;
+		parts |= RectPart::None;
 		if (paintTopRounded) parts |= RectPart::FullTop;
 		if (paintBottomRounded) parts |= RectPart::FullBottom;
 		App::roundRect(p, rect(), st::boxBg, BoxCorners, nullptr, parts);
@@ -421,3 +420,22 @@ void AbstractBox::keyPressEvent(QKeyEvent *e) {
 		LayerWidget::keyPressEvent(e);
 	}
 }
+
+BoxLayerTitleShadow::BoxLayerTitleShadow(QWidget *parent) : Ui::PlainShadow(parent, st::boxLayerTitleShadow) {
+}
+
+BoxContentDivider::BoxContentDivider(QWidget *parent) : TWidget(parent) {
+}
+
+int BoxContentDivider::resizeGetHeight(int newWidth) {
+	return st::rightsDividerHeight;
+}
+
+void BoxContentDivider::paintEvent(QPaintEvent *e) {
+	Painter p(this);
+	p.fillRect(e->rect(), st::contactsAboutBg);
+	auto dividerFillTop = myrtlrect(0, 0, width(), st::profileDividerTop.height());
+	st::profileDividerTop.fill(p, dividerFillTop);
+	auto dividerFillBottom = myrtlrect(0, height() - st::profileDividerBottom.height(), width(), st::profileDividerBottom.height());
+	st::profileDividerBottom.fill(p, dividerFillBottom);
+}
