@@ -25,30 +25,31 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "ui/widgets/labels.h"
 #include "ui/widgets/buttons.h"
 #include "ui/effects/widget_slide_wrap.h"
-#include "boxes/peer_list_box.h"
+#include "boxes/peer_list_controllers.h"
 #include "apiwrap.h"
+#include "auth_session.h"
 #include "lang/lang_keys.h"
 
 namespace {
 
 class PrivacyExceptionsBoxController : public ChatsListBoxController {
 public:
-	PrivacyExceptionsBoxController(base::lambda<QString()> titleFactory, const std::vector<gsl::not_null<UserData*>> &selected);
-	void rowClicked(gsl::not_null<PeerListRow*> row) override;
+	PrivacyExceptionsBoxController(base::lambda<QString()> titleFactory, const std::vector<not_null<UserData*>> &selected);
+	void rowClicked(not_null<PeerListRow*> row) override;
 
-	std::vector<gsl::not_null<UserData*>> getResult() const;
+	std::vector<not_null<UserData*>> getResult() const;
 
 protected:
 	void prepareViewHook() override;
-	std::unique_ptr<Row> createRow(gsl::not_null<History*> history) override;
+	std::unique_ptr<Row> createRow(not_null<History*> history) override;
 
 private:
 	base::lambda<QString()> _titleFactory;
-	std::vector<gsl::not_null<UserData*>> _selected;
+	std::vector<not_null<UserData*>> _selected;
 
 };
 
-PrivacyExceptionsBoxController::PrivacyExceptionsBoxController(base::lambda<QString()> titleFactory, const std::vector<gsl::not_null<UserData*>> &selected)
+PrivacyExceptionsBoxController::PrivacyExceptionsBoxController(base::lambda<QString()> titleFactory, const std::vector<not_null<UserData*>> &selected)
 : _titleFactory(std::move(titleFactory))
 , _selected(selected) {
 }
@@ -58,31 +59,32 @@ void PrivacyExceptionsBoxController::prepareViewHook() {
 	delegate()->peerListAddSelectedRows(_selected);
 }
 
-std::vector<gsl::not_null<UserData*>> PrivacyExceptionsBoxController::getResult() const {
+std::vector<not_null<UserData*>> PrivacyExceptionsBoxController::getResult() const {
 	auto peers = delegate()->peerListCollectSelectedRows();
-	auto users = std::vector<gsl::not_null<UserData*>>();
+	auto users = std::vector<not_null<UserData*>>();
 	if (!peers.empty()) {
 		users.reserve(peers.size());
 		for_const (auto peer, peers) {
 			auto user = peer->asUser();
-			t_assert(user != nullptr);
+			Assert(user != nullptr);
 			users.push_back(user);
 		}
 	}
 	return users;
 }
 
-void PrivacyExceptionsBoxController::rowClicked(gsl::not_null<PeerListRow*> row) {
+void PrivacyExceptionsBoxController::rowClicked(not_null<PeerListRow*> row) {
 	delegate()->peerListSetRowChecked(row, !row->checked());
 }
 
-std::unique_ptr<PrivacyExceptionsBoxController::Row> PrivacyExceptionsBoxController::createRow(gsl::not_null<History*> history) {
-	if (auto user = history->peer->asUser()) {
-		if (!user->isSelf()) {
-			return std::make_unique<Row>(history);
-		}
+std::unique_ptr<PrivacyExceptionsBoxController::Row> PrivacyExceptionsBoxController::createRow(not_null<History*> history) {
+	if (history->peer->isSelf()) {
+		return nullptr;
 	}
-	return std::unique_ptr<Row>();
+	if (auto user = history->peer->asUser()) {
+		return std::make_unique<Row>(history);
+	}
+	return nullptr;
 }
 
 } // namespace
@@ -176,7 +178,7 @@ void EditPrivacyBox::editExceptionUsers(Exception exception) {
 	auto controller = std::make_unique<PrivacyExceptionsBoxController>(base::lambda_guarded(this, [this, exception] {
 		return _controller->exceptionBoxTitle(exception);
 	}), exceptionUsers(exception));
-	auto initBox = [this, exception, controller = controller.get()](PeerListBox *box) {
+	auto initBox = [this, exception, controller = controller.get()](not_null<PeerListBox*> box) {
 		box->addButton(langFactory(lng_settings_save), base::lambda_guarded(this, [this, box, exception, controller] {
 			exceptionUsers(exception) = controller->getResult();
 			exceptionLink(exception)->entity()->setText(exceptionLinkText(exception));
@@ -242,7 +244,7 @@ style::margins EditPrivacyBox::exceptionLinkMargins() const {
 	return st::editPrivacyLinkMargin;
 }
 
-std::vector<gsl::not_null<UserData*>> &EditPrivacyBox::exceptionUsers(Exception exception) {
+std::vector<not_null<UserData*>> &EditPrivacyBox::exceptionUsers(Exception exception) {
 	switch (exception) {
 	case Exception::Always: return _alwaysUsers;
 	case Exception::Never: return _neverUsers;
@@ -302,7 +304,7 @@ void EditPrivacyBox::createWidgets() {
 	addButton(langFactory(lng_settings_save), [this] {
 		auto someAreDisallowed = (_option != Option::Everyone) || !_neverUsers.empty();
 		_controller->confirmSave(someAreDisallowed, base::lambda_guarded(this, [this] {
-			App::api()->savePrivacy(_controller->key(), collectResult());
+			Auth().api().savePrivacy(_controller->key(), collectResult());
 			closeBox();
 		}));
 	});
