@@ -20,16 +20,16 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 */
 #pragma once
 
+#include "lang/lang_cloud_manager.h"
 #include "boxes/abstract_box.h"
+#include "mtproto/sender.h"
 
 namespace Ui {
 class RadiobuttonGroup;
 class Radiobutton;
 } // namespace Ui
 
-class LanguageBox : public BoxContent {
-	Q_OBJECT
-
+class LanguageBox : public BoxContent, private MTP::Sender  {
 public:
 	LanguageBox(QWidget*) {
 	}
@@ -37,12 +37,16 @@ public:
 protected:
 	void prepare() override;
 
-	void mousePressEvent(QMouseEvent *e) override;
-
 private:
-	void languageChanged(int languageId);
+	using Languages = Lang::CloudManager::Languages;
 
-	std::shared_ptr<Ui::RadiobuttonGroup> _langGroup;
-	std::vector<object_ptr<Ui::Radiobutton>> _langs;
+	void refresh();
+	void refreshLanguages();
+	void refreshLang();
+
+	Languages _languages;
+
+	class Inner;
+	QPointer<Inner> _inner;
 
 };
