@@ -33,14 +33,29 @@ class WidgetSlideWrap;
 class FlatLabel;
 } // namespace Ui
 
+namespace Notify {
+struct PeerUpdate;
+} // namespace Notify
+
+inline auto PaintUserpicCallback(PeerData *peer) {
+	return [peer](Painter &p, int x, int y, int outerWidth, int size) {
+		peer->paintUserpicLeft(p, x, y, outerWidth, size);
+	};
+}
+
 using PeerListRowId = uint64;
 class PeerListRow {
 public:
-	PeerListRow(gsl::not_null<PeerData*> peer);
-	PeerListRow(gsl::not_null<PeerData*> peer, PeerListRowId id);
+	PeerListRow(not_null<PeerData*> peer);
+	PeerListRow(not_null<PeerData*> peer, PeerListRowId id);
 
-	void setDisabled(bool disabled) {
-		_disabled = disabled;
+	enum class State {
+		Active,
+		Disabled,
+		DisabledChecked,
+	};
+	void setDisabledState(State state) {
+		_disabledState = state;
 	}
 
 	// Checked state is controlled by the box with multiselect,
@@ -49,7 +64,7 @@ public:
 	// added to the box it is always false.
 	bool checked() const;
 
-	gsl::not_null<PeerData*> peer() const {
+	not_null<PeerData*> peer() const {
 		return _peer;
 	}
 	PeerListRowId id() const {
@@ -97,7 +112,7 @@ public:
 		return _absoluteIndex;
 	}
 	bool disabled() const {
-		return _disabled;
+		return (_disabledState != State::Active);
 	}
 	bool isSearchResult() const {
 		return _isSearchResult;
@@ -148,7 +163,7 @@ private:
 	void setStatusText(const QString &text);
 
 	PeerListRowId _id = 0;
-	gsl::not_null<PeerData*> _peer;
+	not_null<PeerData*> _peer;
 	std::unique_ptr<Ui::RippleAnimation> _ripple;
 	std::unique_ptr<Ui::RoundImageCheckbox> _checkbox;
 	Text _name;
@@ -156,8 +171,8 @@ private:
 	StatusType _statusType = StatusType::Online;
 	OrderedSet<QChar> _nameFirstChars;
 	int _absoluteIndex = -1;
+	State _disabledState = State::Active;
 	bool _initialized : 1;
-	bool _disabled : 1;
 	bool _isSearchResult : 1;
 
 };
@@ -170,21 +185,23 @@ enum class PeerListSearchMode {
 class PeerListDelegate {
 public:
 	virtual void peerListSetTitle(base::lambda<QString()> title) = 0;
+	virtual void peerListSetAdditionalTitle(base::lambda<QString()> title) = 0;
 	virtual void peerListSetDescription(object_ptr<Ui::FlatLabel> description) = 0;
 	virtual void peerListSetSearchLoading(object_ptr<Ui::FlatLabel> loading) = 0;
 	virtual void peerListSetSearchNoResults(object_ptr<Ui::FlatLabel> noResults) = 0;
+	virtual void peerListSetAboveWidget(object_ptr<TWidget> aboveWidget) = 0;
 	virtual void peerListSetSearchMode(PeerListSearchMode mode) = 0;
 	virtual void peerListAppendRow(std::unique_ptr<PeerListRow> row) = 0;
 	virtual void peerListAppendSearchRow(std::unique_ptr<PeerListRow> row) = 0;
-	virtual void peerListAppendFoundRow(gsl::not_null<PeerListRow*> row) = 0;
+	virtual void peerListAppendFoundRow(not_null<PeerListRow*> row) = 0;
 	virtual void peerListPrependRow(std::unique_ptr<PeerListRow> row) = 0;
-	virtual void peerListPrependRowFromSearchResult(gsl::not_null<PeerListRow*> row) = 0;
-	virtual void peerListUpdateRow(gsl::not_null<PeerListRow*> row) = 0;
-	virtual void peerListRemoveRow(gsl::not_null<PeerListRow*> row) = 0;
-	virtual void peerListConvertRowToSearchResult(gsl::not_null<PeerListRow*> row) = 0;
-	virtual bool peerListIsRowSelected(gsl::not_null<PeerData*> peer) = 0;
-	virtual void peerListSetRowChecked(gsl::not_null<PeerListRow*> row, bool checked) = 0;
-	virtual gsl::not_null<PeerListRow*> peerListRowAt(int index) = 0;
+	virtual void peerListPrependRowFromSearchResult(not_null<PeerListRow*> row) = 0;
+	virtual void peerListUpdateRow(not_null<PeerListRow*> row) = 0;
+	virtual void peerListRemoveRow(not_null<PeerListRow*> row) = 0;
+	virtual void peerListConvertRowToSearchResult(not_null<PeerListRow*> row) = 0;
+	virtual bool peerListIsRowSelected(not_null<PeerData*> peer) = 0;
+	virtual void peerListSetRowChecked(not_null<PeerListRow*> row, bool checked) = 0;
+	virtual not_null<PeerListRow*> peerListRowAt(int index) = 0;
 	virtual void peerListRefreshRows() = 0;
 	virtual void peerListScrollToTop() = 0;
 	virtual int peerListFullRowsCount() = 0;
@@ -200,18 +217,19 @@ public:
 		peerListFinishSelectedRowsBunch();
 	}
 
-	virtual std::vector<gsl::not_null<PeerData*>> peerListCollectSelectedRows() = 0;
+	virtual int peerListSelectedRowsCount() = 0;
+	virtual std::vector<not_null<PeerData*>> peerListCollectSelectedRows() = 0;
 	virtual ~PeerListDelegate() = default;
 
 private:
-	virtual void peerListAddSelectedRowInBunch(gsl::not_null<PeerData*> peer) = 0;
+	virtual void peerListAddSelectedRowInBunch(not_null<PeerData*> peer) = 0;
 	virtual void peerListFinishSelectedRowsBunch() = 0;
 
 };
 
 class PeerListSearchDelegate {
 public:
-	virtual void peerListSearchAddRow(gsl::not_null<PeerData*> peer) = 0;
+	virtual void peerListSearchAddRow(not_null<PeerData*> peer) = 0;
 	virtual void peerListSearchRefreshRows() = 0;
 	virtual ~PeerListSearchDelegate() = default;
 
@@ -224,12 +242,12 @@ public:
 	virtual bool loadMoreRows() = 0;
 	virtual ~PeerListSearchController() = default;
 
-	void setDelegate(gsl::not_null<PeerListSearchDelegate*> delegate) {
+	void setDelegate(not_null<PeerListSearchDelegate*> delegate) {
 		_delegate = delegate;
 	}
 
 protected:
-	gsl::not_null<PeerListSearchDelegate*> delegate() const {
+	not_null<PeerListSearchDelegate*> delegate() const {
 		return _delegate;
 	}
 
@@ -243,25 +261,27 @@ public:
 	// Search works only with RowId == peer->id.
 	PeerListController(std::unique_ptr<PeerListSearchController> searchController = nullptr);
 
-	void setDelegate(gsl::not_null<PeerListDelegate*> delegate) {
+	void setDelegate(not_null<PeerListDelegate*> delegate) {
 		_delegate = delegate;
 		prepare();
 	}
 
 	virtual void prepare() = 0;
-	virtual void rowClicked(gsl::not_null<PeerListRow*> row) = 0;
-	virtual void rowActionClicked(gsl::not_null<PeerListRow*> row) {
+	virtual void rowClicked(not_null<PeerListRow*> row) = 0;
+	virtual void rowActionClicked(not_null<PeerListRow*> row) {
 	}
 	virtual void loadMoreRows() {
 	}
+	virtual void itemDeselectedHook(not_null<PeerData*> peer) {
+	}
 	bool isSearchLoading() const {
 		return _searchController ? _searchController->isLoading() : false;
 	}
-	virtual std::unique_ptr<PeerListRow> createSearchRow(gsl::not_null<PeerData*> peer) {
-		return std::unique_ptr<PeerListRow>();
+	virtual std::unique_ptr<PeerListRow> createSearchRow(not_null<PeerData*> peer) {
+		return nullptr;
 	}
 
-	bool isRowSelected(gsl::not_null<PeerData*> peer) {
+	bool isRowSelected(not_null<PeerData*> peer) {
 		return delegate()->peerListIsRowSelected(peer);
 	}
 
@@ -271,13 +291,13 @@ public:
 	bool hasComplexSearch() const;
 	void search(const QString &query);
 
-	void peerListSearchAddRow(gsl::not_null<PeerData*> peer) override;
+	void peerListSearchAddRow(not_null<PeerData*> peer) override;
 	void peerListSearchRefreshRows() override;
 
 	virtual ~PeerListController() = default;
 
 protected:
-	gsl::not_null<PeerListDelegate*> delegate() const {
+	not_null<PeerListDelegate*> delegate() const {
 		return _delegate;
 	}
 	PeerListSearchController *searchController() const {
@@ -305,27 +325,32 @@ private:
 
 class PeerListBox : public BoxContent, public PeerListDelegate {
 public:
-	PeerListBox(QWidget*, std::unique_ptr<PeerListController> controller, base::lambda<void(PeerListBox*)> init);
+	PeerListBox(QWidget*, std::unique_ptr<PeerListController> controller, base::lambda<void(not_null<PeerListBox*>)> init);
 
 	void peerListSetTitle(base::lambda<QString()> title) override {
 		setTitle(std::move(title));
 	}
+	void peerListSetAdditionalTitle(base::lambda<QString()> title) override {
+		setAdditionalTitle(std::move(title));
+	}
 	void peerListSetDescription(object_ptr<Ui::FlatLabel> description) override;
 	void peerListSetSearchLoading(object_ptr<Ui::FlatLabel> loading) override;
 	void peerListSetSearchNoResults(object_ptr<Ui::FlatLabel> noResults) override;
+	void peerListSetAboveWidget(object_ptr<TWidget> aboveWidget) override;
 	void peerListSetSearchMode(PeerListSearchMode mode) override;
 	void peerListAppendRow(std::unique_ptr<PeerListRow> row) override;
 	void peerListAppendSearchRow(std::unique_ptr<PeerListRow> row) override;
-	void peerListAppendFoundRow(gsl::not_null<PeerListRow*> row) override;
+	void peerListAppendFoundRow(not_null<PeerListRow*> row) override;
 	void peerListPrependRow(std::unique_ptr<PeerListRow> row) override;
-	void peerListPrependRowFromSearchResult(gsl::not_null<PeerListRow*> row) override;
-	void peerListUpdateRow(gsl::not_null<PeerListRow*> row) override;
-	void peerListRemoveRow(gsl::not_null<PeerListRow*> row) override;
-	void peerListConvertRowToSearchResult(gsl::not_null<PeerListRow*> row) override;
-	void peerListSetRowChecked(gsl::not_null<PeerListRow*> row, bool checked) override;
-	gsl::not_null<PeerListRow*> peerListRowAt(int index) override;
-	bool peerListIsRowSelected(gsl::not_null<PeerData*> peer) override;
-	std::vector<gsl::not_null<PeerData*>> peerListCollectSelectedRows() override;
+	void peerListPrependRowFromSearchResult(not_null<PeerListRow*> row) override;
+	void peerListUpdateRow(not_null<PeerListRow*> row) override;
+	void peerListRemoveRow(not_null<PeerListRow*> row) override;
+	void peerListConvertRowToSearchResult(not_null<PeerListRow*> row) override;
+	void peerListSetRowChecked(not_null<PeerListRow*> row, bool checked) override;
+	not_null<PeerListRow*> peerListRowAt(int index) override;
+	bool peerListIsRowSelected(not_null<PeerData*> peer) override;
+	int peerListSelectedRowsCount() override;
+	std::vector<not_null<PeerData*>> peerListCollectSelectedRows() override;
 	void peerListRefreshRows() override;
 	void peerListScrollToTop() override;
 	int peerListFullRowsCount() override;
@@ -342,13 +367,13 @@ protected:
 	void paintEvent(QPaintEvent *e) override;
 
 private:
-	void peerListAddSelectedRowInBunch(gsl::not_null<PeerData*> peer) override {
+	void peerListAddSelectedRowInBunch(not_null<PeerData*> peer) override {
 		addSelectItem(peer, PeerListRow::SetStyle::Fast);
 	}
 	void peerListFinishSelectedRowsBunch() override;
 
-	void addSelectItem(gsl::not_null<PeerData*> peer, PeerListRow::SetStyle style);
-	object_ptr<Ui::WidgetSlideWrap<Ui::MultiSelect>> createMultiSelect();
+	void addSelectItem(not_null<PeerData*> peer, PeerListRow::SetStyle style);
+	void createMultiSelect();
 	int getTopScrollSkip() const;
 	void updateScrollSkips();
 	void searchQueryChanged(const QString &query);
@@ -360,6 +385,7 @@ private:
 
 	std::unique_ptr<PeerListController> _controller;
 	base::lambda<void(PeerListBox*)> _init;
+	bool _scrollBottomFixed = true;
 
 };
 
@@ -368,7 +394,7 @@ class PeerListBox::Inner : public TWidget, private base::Subscriber {
 	Q_OBJECT
 
 public:
-	Inner(QWidget *parent, gsl::not_null<PeerListController*> controller);
+	Inner(QWidget *parent, not_null<PeerListController*> controller);
 
 	void selectSkip(int direction);
 	void selectSkipPage(int height, int direction);
@@ -383,24 +409,25 @@ public:
 	// Interface for the controller.
 	void appendRow(std::unique_ptr<PeerListRow> row);
 	void appendSearchRow(std::unique_ptr<PeerListRow> row);
-	void appendFoundRow(gsl::not_null<PeerListRow*> row);
+	void appendFoundRow(not_null<PeerListRow*> row);
 	void prependRow(std::unique_ptr<PeerListRow> row);
-	void prependRowFromSearchResult(gsl::not_null<PeerListRow*> row);
+	void prependRowFromSearchResult(not_null<PeerListRow*> row);
 	PeerListRow *findRow(PeerListRowId id);
-	void updateRow(gsl::not_null<PeerListRow*> row) {
+	void updateRow(not_null<PeerListRow*> row) {
 		updateRow(row, RowIndex());
 	}
-	void removeRow(gsl::not_null<PeerListRow*> row);
-	void convertRowToSearchResult(gsl::not_null<PeerListRow*> row);
+	void removeRow(not_null<PeerListRow*> row);
+	void convertRowToSearchResult(not_null<PeerListRow*> row);
 	int fullRowsCount() const;
-	gsl::not_null<PeerListRow*> rowAt(int index) const;
+	not_null<PeerListRow*> rowAt(int index) const;
 	void setDescription(object_ptr<Ui::FlatLabel> description);
 	void setSearchLoading(object_ptr<Ui::FlatLabel> loading);
 	void setSearchNoResults(object_ptr<Ui::FlatLabel> noResults);
+	void setAboveWidget(object_ptr<TWidget> aboveWidget);
 	void refreshRows();
 
 	void setSearchMode(PeerListSearchMode mode);
-	void changeCheckState(gsl::not_null<PeerListRow*> row, bool checked, PeerListRow::SetStyle style);
+	void changeCheckState(not_null<PeerListRow*> row, bool checked, PeerListRow::SetStyle style);
 
 	template <typename ReorderCallback>
 	void reorderRows(ReorderCallback &&callback) {
@@ -415,10 +442,10 @@ signals:
 	void mustScrollTo(int ymin, int ymax);
 
 public slots:
-	void peerUpdated(PeerData *peer);
-	void onPeerNameChanged(PeerData *peer, const PeerData::Names &oldNames, const PeerData::NameFirstChars &oldChars);
 
 protected:
+	int resizeGetHeight(int newWidth) override;
+
 	void paintEvent(QPaintEvent *e) override;
 	void enterEventHook(QEvent *e) override;
 	void leaveEventHook(QEvent *e) override;
@@ -429,6 +456,7 @@ protected:
 private:
 	void refreshIndices();
 	void removeRowAtIndex(std::vector<std::unique_ptr<PeerListRow>> &from, int index);
+	void handleNameChanged(const Notify::PeerUpdate &update);
 
 	void invalidatePixmapsCache();
 
@@ -471,19 +499,19 @@ private:
 	void loadProfilePhotos();
 	void checkScrollForPreload();
 
-	void updateRow(gsl::not_null<PeerListRow*> row, RowIndex hint);
+	void updateRow(not_null<PeerListRow*> row, RowIndex hint);
 	void updateRow(RowIndex row);
 	int getRowTop(RowIndex row) const;
 	PeerListRow *getRow(RowIndex element);
-	RowIndex findRowIndex(gsl::not_null<PeerListRow*> row, RowIndex hint = RowIndex());
-	QRect getActionRect(gsl::not_null<PeerListRow*> row, RowIndex index) const;
+	RowIndex findRowIndex(not_null<PeerListRow*> row, RowIndex hint = RowIndex());
+	QRect getActionRect(not_null<PeerListRow*> row, RowIndex index) const;
 
 	void paintRow(Painter &p, TimeMs ms, RowIndex index);
 
-	void addRowEntry(gsl::not_null<PeerListRow*> row);
-	void addToSearchIndex(gsl::not_null<PeerListRow*> row);
+	void addRowEntry(not_null<PeerListRow*> row);
+	void addToSearchIndex(not_null<PeerListRow*> row);
 	bool addingToSearchIndex() const;
-	void removeFromSearchIndex(gsl::not_null<PeerListRow*> row);
+	void removeFromSearchIndex(not_null<PeerListRow*> row);
 	void setSearchQuery(const QString &query, const QString &normalizedQuery);
 	bool showingSearch() const {
 		return !_searchQuery.isEmpty();
@@ -496,11 +524,12 @@ private:
 	template <typename Callback>
 	bool enumerateShownRows(int from, int to, Callback callback);
 
+	int rowsTop() const;
 	int labelHeight() const;
 
 	void clearSearchRows();
 
-	gsl::not_null<PeerListController*> _controller;
+	not_null<PeerListController*> _controller;
 	PeerListSearchMode _searchMode = PeerListSearchMode::Disabled;
 
 	int _rowHeight = 0;
@@ -512,15 +541,17 @@ private:
 	bool _mouseSelection = false;
 
 	std::vector<std::unique_ptr<PeerListRow>> _rows;
-	std::map<PeerListRowId, gsl::not_null<PeerListRow*>> _rowsById;
-	std::map<PeerData*, std::vector<gsl::not_null<PeerListRow*>>> _rowsByPeer;
+	std::map<PeerListRowId, not_null<PeerListRow*>> _rowsById;
+	std::map<PeerData*, std::vector<not_null<PeerListRow*>>> _rowsByPeer;
 
-	std::map<QChar, std::vector<gsl::not_null<PeerListRow*>>> _searchIndex;
+	std::map<QChar, std::vector<not_null<PeerListRow*>>> _searchIndex;
 	QString _searchQuery;
 	QString _normalizedSearchQuery;
 	QString _mentionHighlight;
-	std::vector<gsl::not_null<PeerListRow*>> _filterResults;
+	std::vector<not_null<PeerListRow*>> _filterResults;
 
+	int _aboveHeight = 0;
+	object_ptr<TWidget> _aboveWidget = { nullptr };
 	object_ptr<Ui::FlatLabel> _description = { nullptr };
 	object_ptr<Ui::FlatLabel> _searchNoResults = { nullptr };
 	object_ptr<Ui::FlatLabel> _searchLoading = { nullptr };
@@ -530,77 +561,3 @@ private:
 	std::vector<std::unique_ptr<PeerListRow>> _searchRows;
 
 };
-
-class PeerListRowWithLink : public PeerListRow {
-public:
-	using PeerListRow::PeerListRow;
-
-	void setActionLink(const QString &action);
-
-	void lazyInitialize() override;
-
-private:
-	void refreshActionLink();
-	QSize actionSize() const override;
-	QMargins actionMargins() const override;
-	void paintAction(Painter &p, TimeMs ms, int x, int y, int outerWidth, bool actionSelected) override;
-
-	QString _action;
-	int _actionWidth = 0;
-
-};
-
-class PeerListGlobalSearchController : public PeerListSearchController, private MTP::Sender {
-public:
-	PeerListGlobalSearchController();
-
-	void searchQuery(const QString &query) override;
-	bool isLoading() override;
-	bool loadMoreRows() override {
-		return false;
-	}
-
-private:
-	bool searchInCache();
-	void searchOnServer();
-	void searchDone(const MTPcontacts_Found &result, mtpRequestId requestId);
-
-	base::Timer _timer;
-	QString _query;
-	mtpRequestId _requestId = 0;
-	std::map<QString, MTPcontacts_Found> _cache;
-	std::map<mtpRequestId, QString> _queries;
-
-};
-
-class ChatsListBoxController : public PeerListController, protected base::Subscriber {
-public:
-	ChatsListBoxController(std::unique_ptr<PeerListSearchController> searchController = std::make_unique<PeerListGlobalSearchController>());
-
-	void prepare() override final;
-	std::unique_ptr<PeerListRow> createSearchRow(gsl::not_null<PeerData*> peer) override final;
-
-protected:
-	class Row : public PeerListRow {
-	public:
-		Row(gsl::not_null<History*> history) : PeerListRow(history->peer), _history(history) {
-		}
-		gsl::not_null<History*> history() const {
-			return _history;
-		}
-
-	private:
-		gsl::not_null<History*> _history;
-
-	};
-	virtual std::unique_ptr<Row> createRow(gsl::not_null<History*> history) = 0;
-	virtual void prepareViewHook() = 0;
-	virtual void updateRowHook(Row *row) {
-	}
-
-private:
-	void rebuildRows();
-	void checkForEmptyRows();
-	bool appendRow(History *history);
-
-};
