@@ -77,7 +77,7 @@ uint64 ComputeFingerprint(const std::array<gsl::byte, kFingerprintDataSize> &aut
 
 } // namespace
 
-Call::Call(gsl::not_null<Delegate*> delegate, gsl::not_null<UserData*> user, Type type)
+Call::Call(not_null<Delegate*> delegate, not_null<UserData*> user, Type type)
 : _delegate(delegate)
 , _user(user)
 , _type(type) {
@@ -118,8 +118,8 @@ void Call::start(base::const_byte_span random) {
 	// Save config here, because it is possible that it changes between
 	// different usages inside the same call.
 	_dhConfig = _delegate->getDhConfig();
-	t_assert(_dhConfig.g != 0);
-	t_assert(!_dhConfig.p.empty());
+	Assert(_dhConfig.g != 0);
+	Assert(!_dhConfig.p.empty());
 
 	generateModExpFirst(random);
 	if (_state == State::Starting || _state == State::Requesting) {
@@ -242,7 +242,7 @@ void Call::redial() {
 	if (_state != State::Busy) {
 		return;
 	}
-	t_assert(_controller == nullptr);
+	Assert(_controller == nullptr);
 	_type = Type::Outgoing;
 	setState(State::Requesting);
 	_answerAfterDhConfigReceived = false;
@@ -261,7 +261,7 @@ QString Call::getDebugLog() const {
 
 void Call::startWaitingTrack() {
 	_waitingTrack = Media::Audio::Current().createTrack();
-	auto trackFileName = AuthSession::Current().data().getSoundPath((_type == Type::Outgoing) ? qsl("call_outgoing") : qsl("call_incoming"));
+	auto trackFileName = Auth().data().getSoundPath((_type == Type::Outgoing) ? qsl("call_outgoing") : qsl("call_incoming"));
 	_waitingTrack->samplePeakEach(kSoundSampleMs);
 	_waitingTrack->fillFromFile(trackFileName);
 	_waitingTrack->playInLoop();
@@ -297,8 +297,8 @@ bool Call::handleUpdate(const MTPPhoneCall &call) {
 			|| peerToUser(_user->id) != data.vadmin_id.v) {
 			Unexpected("phoneCallRequested call inside an existing call handleUpdate()");
 		}
-		if (AuthSession::CurrentUserId() != data.vparticipant_id.v) {
-			LOG(("Call Error: Wrong call participant_id %1, expected %2.").arg(data.vparticipant_id.v).arg(AuthSession::CurrentUserId()));
+		if (Auth().userId() != data.vparticipant_id.v) {
+			LOG(("Call Error: Wrong call participant_id %1, expected %2.").arg(data.vparticipant_id.v).arg(Auth().userId()));
 			finish(FinishType::Failed);
 			return true;
 		}
@@ -531,8 +531,8 @@ bool Call::checkCallCommonFields(const T &call) {
 		LOG(("Call Error: Wrong call access_hash."));
 		return checkFailed();
 	}
-	auto adminId = (_type == Type::Outgoing) ? AuthSession::CurrentUserId() : peerToUser(_user->id);
-	auto participantId = (_type == Type::Outgoing) ? peerToUser(_user->id) : AuthSession::CurrentUserId();
+	auto adminId = (_type == Type::Outgoing) ? Auth().userId() : peerToUser(_user->id);
+	auto participantId = (_type == Type::Outgoing) ? peerToUser(_user->id) : Auth().userId();
 	if (call.vadmin_id.v != adminId) {
 		LOG(("Call Error: Wrong call admin_id %1, expected %2.").arg(call.vadmin_id.v).arg(adminId));
 		return checkFailed();
