@@ -26,10 +26,13 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "codegen/common/cpp_file.h"
 #include "codegen/emoji/options.h"
 #include "codegen/emoji/data.h"
+#include "codegen/emoji/replaces.h"
 
 namespace codegen {
 namespace emoji {
 
+using uint32 = unsigned int;
+
 class Generator {
 public:
 	Generator(const Options &options);
@@ -46,16 +49,24 @@ private:
 
 	bool writeSource();
 	bool writeHeader();
+	bool writeSuggestionsSource();
+	bool writeSuggestionsHeader();
 
 	template <typename Callback>
 	bool enumerateWholeList(Callback callback);
 
 	bool writeInitCode();
 	bool writeSections();
+	bool writeReplacements();
 	bool writeGetSections();
 	bool writeFindReplace();
 	bool writeFind();
 	bool writeFindFromDictionary(const std::map<QString, int, std::greater<QString>> &dictionary, bool skipPostfixes = false);
+	bool writeGetReplacements();
+	void startBinary();
+	bool writeStringBinary(common::CppFile *source, const QString &string);
+	void writeIntBinary(common::CppFile *source, int data);
+	void writeUintBinary(common::CppFile *source, uint32 data);
 
 	const common::ProjectInfo &project_;
 	int colorsCount_ = 0;
@@ -67,6 +78,13 @@ private:
 	std::unique_ptr<common::CppFile> source_;
 	Data data_;
 
+	QString suggestionsPath_;
+	std::unique_ptr<common::CppFile> suggestionsSource_;
+	Replaces replaces_;
+
+	int _binaryFullLength = 0;
+	int _binaryCount = 0;
+
 };
 
 } // namespace emoji
