@@ -30,10 +30,6 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "ui/widgets/tooltip.h"
 #include "core/file_utilities.h"
 
-QString UrlClickHandler::copyToClipboardContextItemText() const {
-	return lang(isEmail() ? lng_context_copy_email : lng_context_copy_link);
-}
-
 namespace {
 
 QString tryConvertUrlToLocal(QString url) {
@@ -73,8 +69,31 @@ QString tryConvertUrlToLocal(QString url) {
 	return url;
 }
 
+bool UrlRequiresConfirmation(const QUrl &url) {
+	using namespace qthelp;
+	return !regex_match(qsl("(^|\\.)(telegram\\.org|telegra\\.ph|telesco\\.pe)$"), url.host(), RegExOption::CaseInsensitive);
+}
+
 } // namespace
 
+QString UrlClickHandler::copyToClipboardContextItemText() const {
+	return lang(isEmail() ? lng_context_copy_email : lng_context_copy_link);
+}
+
+QString UrlClickHandler::url() const {
+	if (isEmail()) {
+		return _originalUrl;
+	}
+
+	QUrl u(_originalUrl), good(u.isValid() ? u.toEncoded() : QString());
+	QString result(good.isValid() ? QString::fromUtf8(good.toEncoded()) : _originalUrl);
+
+	if (!result.isEmpty() && !QRegularExpression(qsl("^[a-zA-Z]+:")).match(result).hasMatch()) { // no protocol
+		return qsl("http://") + result;
+	}
+	return result;
+}
+
 void UrlClickHandler::doOpen(QString url) {
 	Ui::Tooltip::Hide();
 
@@ -119,11 +138,15 @@ void HiddenUrlClickHandler::doOpen(QString url) {
 		Messenger::Instance().openLocalUrl(urlText);
 	} else {
 		auto parsedUrl = QUrl::fromUserInput(urlText);
-		auto displayUrl = parsedUrl.isValid() ? parsedUrl.toDisplayString() : urlText;
-		Ui::show(Box<ConfirmBox>(lang(lng_open_this_link) + qsl("\n\n") + displayUrl, lang(lng_open_link), [urlText] {
-			Ui::hideLayer();
+		if (UrlRequiresConfirmation(urlText)) {
+			auto displayUrl = parsedUrl.isValid() ? parsedUrl.toDisplayString() : urlText;
+			Ui::show(Box<ConfirmBox>(lang(lng_open_this_link) + qsl("\n\n") + displayUrl, lang(lng_open_link), [urlText] {
+				Ui::hideLayer();
+				UrlClickHandler::doOpen(urlText);
+			}));
+		} else {
 			UrlClickHandler::doOpen(urlText);
-		}));
+		}
 	}
 }
 
