@@ -25,11 +25,14 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "ui/effects/send_action_animations.h"
 #include "base/observer.h"
 #include "base/timer.h"
+#include "base/variant.h"
+#include "base/flat_set.h"
+#include "base/flags.h"
 
 void HistoryInit();
 
 class HistoryItem;
-using SelectedItemSet = QMap<int, gsl::not_null<HistoryItem*>>;
+using SelectedItemSet = QMap<int, not_null<HistoryItem*>>;
 
 enum NewMessageType {
 	NewMessageUnread,
@@ -51,8 +54,8 @@ public:
 	void step_typings(TimeMs ms, bool timer);
 
 	History *find(const PeerId &peerId);
-	History *findOrInsert(const PeerId &peerId);
-	History *findOrInsert(const PeerId &peerId, int32 unreadCount, int32 maxInboxRead, int32 maxOutboxRead);
+	not_null<History*> findOrInsert(const PeerId &peerId);
+	not_null<History*> findOrInsert(const PeerId &peerId, int32 unreadCount, int32 maxInboxRead, int32 maxOutboxRead);
 
 	void clear();
 	void remove(const PeerId &peer);
@@ -97,7 +100,7 @@ public:
 	base::Observable<SendActionAnimationUpdate> &sendActionAnimationUpdated() {
 		return _sendActionAnimationUpdated;
 	}
-	void selfDestructIn(gsl::not_null<HistoryItem*> item, TimeMs delay);
+	void selfDestructIn(not_null<HistoryItem*> item, TimeMs delay);
 
 private:
 	void checkSelfDestructItems();
@@ -208,6 +211,9 @@ public:
 	ChannelHistory *asChannelHistory();
 	const ChannelHistory *asChannelHistory() const;
 
+	not_null<History*> migrateToOrMe() const;
+	History *migrateFrom() const;
+
 	bool isEmpty() const {
 		return blocks.isEmpty();
 	}
@@ -349,7 +355,27 @@ public:
 	// if this returns false there is no need to even try to handle them
 	bool canHaveFromPhotos() const;
 
-	typedef QList<HistoryBlock*> Blocks;
+	int getUnreadMentionsLoadedCount() const {
+		return _unreadMentions.size();
+	}
+	MsgId getMinLoadedUnreadMention() const {
+		return _unreadMentions.empty() ? 0 : _unreadMentions.front();
+	}
+	MsgId getMaxLoadedUnreadMention() const {
+		return _unreadMentions.empty() ? 0 : _unreadMentions.back();
+	}
+	int getUnreadMentionsCount(int notLoadedValue = -1) const {
+		return _unreadMentionsCount ? *_unreadMentionsCount : notLoadedValue;
+	}
+	bool hasUnreadMentions() const {
+		return (getUnreadMentionsCount() > 0);
+	}
+	void setUnreadMentionsCount(int count);
+	bool addToUnreadMentions(MsgId msgId, AddToOverviewMethod method);
+	void eraseFromUnreadMentions(MsgId msgId);
+	void addUnreadMentionsSlice(const MTPmessages_Messages &result);
+
+	using Blocks = QList<HistoryBlock*>;
 	Blocks blocks;
 
 	int width = 0;
@@ -441,37 +467,33 @@ public:
 	mutable const HistoryItem *textCachedFor = nullptr; // cache
 	mutable Text lastItemTextCache;
 
-	typedef QList<MsgId> MediaOverview;
-	MediaOverview overview[OverviewCount];
-
 	bool overviewCountLoaded(int32 overviewIndex) const {
-		return overviewCountData[overviewIndex] >= 0;
+		return _overviewCountData[overviewIndex] >= 0;
 	}
 	bool overviewLoaded(int32 overviewIndex) const {
-		return overviewCount(overviewIndex) == overview[overviewIndex].size();
+		return overviewCount(overviewIndex) == _overview[overviewIndex].size();
 	}
-	int32 overviewCount(int32 overviewIndex, int32 defaultValue = -1) const {
-		int32 result = overviewCountData[overviewIndex], loaded = overview[overviewIndex].size();
+	int overviewCount(int32 overviewIndex, int32 defaultValue = -1) const {
+		auto result = _overviewCountData[overviewIndex];
+		auto loaded = _overview[overviewIndex].size();
 		if (result < 0) return defaultValue;
 		if (result < loaded) {
 			if (result > 0) {
-				const_cast<History*>(this)->overviewCountData[overviewIndex] = 0;
+				const_cast<History*>(this)->_overviewCountData[overviewIndex] = 0;
 			}
 			return loaded;
 		}
 		return result;
 	}
+	const OrderedSet<MsgId> &overview(int32 overviewIndex) const {
+		return _overview[overviewIndex];
+	}
 	MsgId overviewMinId(int32 overviewIndex) const {
-		for_const (auto msgId, overviewIds[overviewIndex]) {
-			if (msgId > 0) {
-				return msgId;
-			}
-		}
-		return 0;
+		return _overview[overviewIndex].empty() ? 0 : *_overview[overviewIndex].begin();
 	}
 	void overviewSliceDone(int32 overviewIndex, const MTPmessages_Messages &result, bool onlyCounts = false);
 	bool overviewHasMsgId(int32 overviewIndex, MsgId msgId) const {
-		return overviewIds[overviewIndex].constFind(msgId) != overviewIds[overviewIndex].cend();
+		return _overview[overviewIndex].contains(msgId);
 	}
 
 	void changeMsgId(MsgId oldId, MsgId newId);
@@ -527,19 +549,15 @@ private:
 		f_has_pending_resized_items = (1 << 0),
 		f_pending_resize            = (1 << 1),
 	};
-	Q_DECLARE_FLAGS(Flags, Flag);
-	Q_DECL_CONSTEXPR friend inline QFlags<Flags::enum_type> operator|(Flags::enum_type f1, Flags::enum_type f2) noexcept {
-		return QFlags<Flags::enum_type>(f1) | f2;
-	}
-	Q_DECL_CONSTEXPR friend inline QFlags<Flags::enum_type> operator|(Flags::enum_type f1, QFlags<Flags::enum_type> f2) noexcept {
-		return f2 | f1;
-	}
-	Q_DECL_CONSTEXPR friend inline QFlags<Flags::enum_type> operator~(Flags::enum_type f) noexcept {
-		return ~QFlags<Flags::enum_type>(f);
-	}
-	Flags _flags;
-	bool _mute;
-	int32 _unreadCount = 0;
+	using Flags = base::flags<Flag>;
+	friend inline constexpr auto is_flag_type(Flag) { return true; };
+
+	Flags _flags = 0;
+	bool _mute = false;
+	int _unreadCount = 0;
+
+	base::optional<int> _unreadMentionsCount;
+	base::flat_set<MsgId> _unreadMentions;
 
 	Dialogs::RowsByLetter _chatListLinks[2];
 	Dialogs::RowsByLetter &chatListLinks(Dialogs::Mode list) {
@@ -550,14 +568,13 @@ private:
 	}
 	Dialogs::Row *mainChatListLink(Dialogs::Mode list) const {
 		auto it = chatListLinks(list).constFind(0);
-		t_assert(it != chatListLinks(list).cend());
+		Assert(it != chatListLinks(list).cend());
 		return it.value();
 	}
 	uint64 _sortKeyInChatList = 0; // like ((unixtime) << 32) | (incremented counter)
 
-	using MediaOverviewIds = OrderedSet<MsgId>;
-	MediaOverviewIds overviewIds[OverviewCount];
-	int32 overviewCountData[OverviewCount]; // -1 - not loaded, 0 - all loaded, > 0 - count, but not all loaded
+	OrderedSet<MsgId> _overview[OverviewCount];
+	int32 _overviewCountData[OverviewCount]; // -1 - not loaded, 0 - all loaded, > 0 - count, but not all loaded
 
 	// A pointer to the block that is currently being built.
 	// We hold this pointer so we can destroy it while building
@@ -626,7 +643,7 @@ private:
 
 class HistoryBlock {
 public:
-	HistoryBlock(gsl::not_null<History*> history) : _history(history) {
+	HistoryBlock(not_null<History*> history) : _history(history) {
 	}
 
 	HistoryBlock(const HistoryBlock &) = delete;
@@ -650,7 +667,7 @@ public:
 	int height() const {
 		return _height;
 	}
-	gsl::not_null<History*> history() const {
+	not_null<History*> history() const {
 		return _history;
 	}
 
@@ -676,7 +693,7 @@ public:
 	}
 
 protected:
-	const gsl::not_null<History*> _history;
+	const not_null<History*> _history;
 
 	int _y = 0;
 	int _height = 0;
