@@ -29,6 +29,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "chat_helpers/message_field.h"
 #include "mainwindow.h"
 #include "mainwidget.h"
+#include "messenger.h"
 #include "apiwrap.h"
 #include "window/window_controller.h"
 #include "auth_session.h"
@@ -71,9 +72,9 @@ void InnerWidget::enumerateItems(Method method) {
 		--from;
 	}
 	if (TopToBottom) {
-		t_assert(itemTop(from->get()) + from->get()->height() > _visibleTop);
+		Assert(itemTop(from->get()) + from->get()->height() > _visibleTop);
 	} else {
-		t_assert(itemTop(from->get()) < _visibleBottom);
+		Assert(itemTop(from->get()) < _visibleBottom);
 	}
 
 	while (true) {
@@ -83,9 +84,9 @@ void InnerWidget::enumerateItems(Method method) {
 
 		// Binary search should've skipped all the items that are above / below the visible area.
 		if (TopToBottom) {
-			t_assert(itembottom > _visibleTop);
+			Assert(itembottom > _visibleTop);
 		} else {
-			t_assert(itemtop < _visibleBottom);
+			Assert(itemtop < _visibleBottom);
 		}
 
 		if (!method(item, itemtop, itembottom)) {
@@ -204,7 +205,7 @@ void InnerWidget::enumerateDates(Method method) {
 	enumerateItems<EnumItemsDirection::BottomToTop>(dateCallback);
 }
 
-InnerWidget::InnerWidget(QWidget *parent, gsl::not_null<Window::Controller*> controller, gsl::not_null<ChannelData*> channel) : TWidget(parent)
+InnerWidget::InnerWidget(QWidget *parent, not_null<Window::Controller*> controller, not_null<ChannelData*> channel) : TWidget(parent)
 , _controller(controller)
 , _channel(channel)
 , _history(App::history(channel))
@@ -212,13 +213,13 @@ InnerWidget::InnerWidget(QWidget *parent, gsl::not_null<Window::Controller*> con
 , _emptyText(st::historyAdminLogEmptyWidth - st::historyAdminLogEmptyPadding.left() - st::historyAdminLogEmptyPadding.left()) {
 	setMouseTracking(true);
 	_scrollDateHideTimer.setCallback([this] { scrollDateHideByTimer(); });
-	subscribe(AuthSession::Current().data().repaintLogEntry(), [this](gsl::not_null<const HistoryItem*> historyItem) {
+	subscribe(Auth().data().repaintLogEntry(), [this](not_null<const HistoryItem*> historyItem) {
 		if (_history == historyItem->history()) {
 			repaintItem(historyItem);
 		}
 	});
-	subscribe(AuthSession::Current().data().pendingHistoryResize(), [this] { handlePendingHistoryResize(); });
-	subscribe(AuthSession::Current().data().queryItemVisibility(), [this](const AuthSessionData::ItemVisibilityQuery &query) {
+	subscribe(Auth().data().pendingHistoryResize(), [this] { handlePendingHistoryResize(); });
+	subscribe(Auth().data().queryItemVisibility(), [this](const AuthSessionData::ItemVisibilityQuery &query) {
 		if (_history != query.item->history() || !query.item->isLogEntry() || !isVisible()) {
 			return;
 		}
@@ -420,7 +421,7 @@ QPoint InnerWidget::tooltipPos() const {
 	return _mousePosition;
 }
 
-void InnerWidget::saveState(gsl::not_null<SectionMemento*> memento) {
+void InnerWidget::saveState(not_null<SectionMemento*> memento) {
 	memento->setFilter(std::move(_filter));
 	memento->setAdmins(std::move(_admins));
 	memento->setAdminsCanEdit(std::move(_adminsCanEdit));
@@ -432,7 +433,7 @@ void InnerWidget::saveState(gsl::not_null<SectionMemento*> memento) {
 	_upLoaded = _downLoaded = true; // Don't load or handle anything anymore.
 }
 
-void InnerWidget::restoreState(gsl::not_null<SectionMemento*> memento) {
+void InnerWidget::restoreState(not_null<SectionMemento*> memento) {
 	_items = memento->takeItems();
 	_itemsByIds = memento->takeItemsByIds();
 	_idManager = memento->takeIdManager();
@@ -508,7 +509,7 @@ void InnerWidget::addEvents(Direction direction, const QVector<MTPChannelAdminLo
 	auto &addToItems = (direction == Direction::Up) ? _items : newItemsForDownDirection;
 	addToItems.reserve(oldItemsCount + events.size() * 2);
 	for_const (auto &event, events) {
-		t_assert(event.type() == mtpc_channelAdminLogEvent);
+		Assert(event.type() == mtpc_channelAdminLogEvent);
 		auto &data = event.c_channelAdminLogEvent();
 		if (_itemsByIds.find(data.vid.v) != _itemsByIds.cend()) {
 			continue;
@@ -634,7 +635,7 @@ void InnerWidget::paintEvent(QPaintEvent *e) {
 			}
 			p.translate(0, -top);
 
-			enumerateUserpics([&p, &clip](gsl::not_null<HistoryMessage*> message, int userpicTop) {
+			enumerateUserpics([&p, &clip](not_null<HistoryMessage*> message, int userpicTop) {
 				// stop the enumeration if the userpic is below the painted rect
 				if (userpicTop >= clip.top() + clip.height()) {
 					return false;
@@ -649,7 +650,7 @@ void InnerWidget::paintEvent(QPaintEvent *e) {
 
 			auto dateHeight = st::msgServicePadding.bottom() + st::msgServiceFont->height + st::msgServicePadding.top();
 			auto scrollDateOpacity = _scrollDateOpacity.current(ms, _scrollDateShown ? 1. : 0.);
-			enumerateDates([&p, &clip, scrollDateOpacity, dateHeight/*, lastDate, showFloatingBefore*/](gsl::not_null<HistoryItem*> item, int itemtop, int dateTop) {
+			enumerateDates([&p, &clip, scrollDateOpacity, dateHeight/*, lastDate, showFloatingBefore*/](not_null<HistoryItem*> item, int itemtop, int dateTop) {
 				// stop the enumeration if the date is above the painted rect
 				if (dateTop + dateHeight <= clip.top()) {
 					return false;
@@ -986,7 +987,7 @@ void InnerWidget::openContextGif() {
 	if (auto item = App::contextItem()) {
 		if (auto media = item->getMedia()) {
 			if (auto document = media->getDocument()) {
-				_controller->window()->showDocument(document, item);
+				Messenger::Instance().showDocument(document, item);
 			}
 		}
 	}
@@ -1007,7 +1008,7 @@ void InnerWidget::setToClipboard(const TextWithEntities &forClipboard, QClipboar
 	}
 }
 
-void InnerWidget::suggestRestrictUser(gsl::not_null<UserData*> user) {
+void InnerWidget::suggestRestrictUser(not_null<UserData*> user) {
 	Expects(_menu != nullptr);
 	if (!_channel->isMegagroup() || !_channel->canBanMembers() || _admins.empty()) {
 		return;
@@ -1053,10 +1054,10 @@ void InnerWidget::suggestRestrictUser(gsl::not_null<UserData*> user) {
 	});
 }
 
-void InnerWidget::restrictUser(gsl::not_null<UserData*> user, const MTPChannelBannedRights &oldRights, const MTPChannelBannedRights &newRights) {
+void InnerWidget::restrictUser(not_null<UserData*> user, const MTPChannelBannedRights &oldRights, const MTPChannelBannedRights &newRights) {
 	auto weak = QPointer<InnerWidget>(this);
 	MTP::send(MTPchannels_EditBanned(_channel->inputChannel, user->inputUser, newRights), rpcDone([megagroup = _channel.get(), user, weak, oldRights, newRights](const MTPUpdates &result) {
-		AuthSession::Current().api().applyUpdates(result);
+		Auth().api().applyUpdates(result);
 		megagroup->applyEditBanned(user, oldRights, newRights);
 		if (weak) {
 			weak->restrictUserDone(user, newRights);
@@ -1064,7 +1065,7 @@ void InnerWidget::restrictUser(gsl::not_null<UserData*> user, const MTPChannelBa
 	}));
 }
 
-void InnerWidget::restrictUserDone(gsl::not_null<UserData*> user, const MTPChannelBannedRights &rights) {
+void InnerWidget::restrictUserDone(not_null<UserData*> user, const MTPChannelBannedRights &rights) {
 	Expects(rights.type() == mtpc_channelBannedRights);
 	if (rights.c_channelBannedRights().vflags.v) {
 		_admins.erase(std::remove(_admins.begin(), _admins.end(), user), _admins.end());
@@ -1289,7 +1290,7 @@ void InnerWidget::updateSelected() {
 		if (!dragState.link && itemPoint.x() >= st::historyPhotoLeft && itemPoint.x() < st::historyPhotoLeft + st::msgPhotoSize) {
 			if (auto message = item->toHistoryMessage()) {
 				if (message->hasFromPhoto()) {
-					enumerateUserpics([&dragState, &lnkhost, &point](gsl::not_null<HistoryMessage*> message, int userpicTop) -> bool {
+					enumerateUserpics([&dragState, &lnkhost, &point](not_null<HistoryMessage*> message, int userpicTop) -> bool {
 						// stop enumeration if the userpic is below our point
 						if (userpicTop > point.y()) {
 							return false;
@@ -1467,7 +1468,7 @@ void InnerWidget::performDrag() {
 	//} // TODO
 }
 
-int InnerWidget::itemTop(gsl::not_null<const HistoryItem*> item) const {
+int InnerWidget::itemTop(not_null<const HistoryItem*> item) const {
 	return _itemsTop + item->y();
 }
 
