@@ -40,13 +40,13 @@ class SectionMemento;
 
 class InnerWidget final : public TWidget, public Ui::AbstractTooltipShower, private MTP::Sender, private base::Subscriber {
 public:
-	InnerWidget(QWidget *parent, gsl::not_null<Window::Controller*> controller, gsl::not_null<ChannelData*> channel);
+	InnerWidget(QWidget *parent, not_null<Window::Controller*> controller, not_null<ChannelData*> channel);
 
 	base::Observable<void> showSearchSignal;
 	base::Observable<int> scrollToSignal;
 	base::Observable<void> cancelledSignal;
 
-	gsl::not_null<ChannelData*> channel() const {
+	not_null<ChannelData*> channel() const {
 		return _channel;
 	}
 
@@ -61,8 +61,8 @@ public:
 		return TWidget::resizeToWidth(newWidth);
 	}
 
-	void saveState(gsl::not_null<SectionMemento*> memento);
-	void restoreState(gsl::not_null<SectionMemento*> memento);
+	void saveState(not_null<SectionMemento*> memento);
+	void restoreState(not_null<SectionMemento*> memento);
 
 	// Empty "flags" means all events.
 	void applyFilter(FilterValue &&value);
@@ -111,7 +111,7 @@ private:
 	void mouseActionCancel();
 	void updateSelected();
 	void performDrag();
-	int itemTop(gsl::not_null<const HistoryItem*> item) const;
+	int itemTop(not_null<const HistoryItem*> item) const;
 	void repaintItem(const HistoryItem *item);
 	QPoint mapPointToItem(QPoint point, const HistoryItem *item) const;
 	void handlePendingHistoryResize();
@@ -129,9 +129,9 @@ private:
 	void copySelectedText();
 	TextWithEntities getSelectedText() const;
 	void setToClipboard(const TextWithEntities &forClipboard, QClipboard::Mode mode = QClipboard::Clipboard);
-	void suggestRestrictUser(gsl::not_null<UserData*> user);
-	void restrictUser(gsl::not_null<UserData*> user, const MTPChannelBannedRights &oldRights, const MTPChannelBannedRights &newRights);
-	void restrictUserDone(gsl::not_null<UserData*> user, const MTPChannelBannedRights &rights);
+	void suggestRestrictUser(not_null<UserData*> user);
+	void restrictUser(not_null<UserData*> user, const MTPChannelBannedRights &oldRights, const MTPChannelBannedRights &newRights);
+	void restrictUserDone(not_null<UserData*> user, const MTPChannelBannedRights &rights);
 
 	void requestAdmins();
 	void checkPreloadMore();
@@ -164,7 +164,7 @@ private:
 	// This function finds all userpics on the left that are displayed and calls template method
 	// for each found userpic (from the top to the bottom) using enumerateItems() method.
 	//
-	// Method has "bool (*Method)(gsl::not_null<HistoryMessage*> message, int userpicTop)" signature
+	// Method has "bool (*Method)(not_null<HistoryMessage*> message, int userpicTop)" signature
 	// if it returns false the enumeration stops immidiately.
 	template <typename Method>
 	void enumerateUserpics(Method method);
@@ -172,14 +172,14 @@ private:
 	// This function finds all date elements that are displayed and calls template method
 	// for each found date element (from the bottom to the top) using enumerateItems() method.
 	//
-	// Method has "bool (*Method)(gsl::not_null<HistoryItem*> item, int itemtop, int dateTop)" signature
+	// Method has "bool (*Method)(not_null<HistoryItem*> item, int itemtop, int dateTop)" signature
 	// if it returns false the enumeration stops immidiately.
 	template <typename Method>
 	void enumerateDates(Method method);
 
-	gsl::not_null<Window::Controller*> _controller;
-	gsl::not_null<ChannelData*> _channel;
-	gsl::not_null<History*> _history;
+	not_null<Window::Controller*> _controller;
+	not_null<ChannelData*> _channel;
+	not_null<History*> _history;
 	std::vector<HistoryItemOwned> _items;
 	std::map<uint64, HistoryItem*> _itemsByIds;
 	int _itemsTop = 0;
@@ -235,8 +235,8 @@ private:
 
 	FilterValue _filter;
 	QString _searchQuery;
-	std::vector<gsl::not_null<UserData*>> _admins;
-	std::vector<gsl::not_null<UserData*>> _adminsCanEdit;
+	std::vector<not_null<UserData*>> _admins;
+	std::vector<not_null<UserData*>> _adminsCanEdit;
 	base::lambda<void(FilterValue &&filter)> _showFilterCallback;
 
 };
