@@ -20,6 +20,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 */
 #pragma once
 
+#include "base/flags.h"
 #include "inline_bots/inline_bot_layout_item.h"
 #include "ui/effects/radial_animation.h"
 #include "ui/text/text.h"
@@ -30,9 +31,9 @@ namespace internal {
 
 class FileBase : public ItemBase {
 public:
-	FileBase(gsl::not_null<Context*> context, Result *result);
+	FileBase(not_null<Context*> context, Result *result);
 	// for saved gif layouts
-	FileBase(gsl::not_null<Context*> context, DocumentData *doc);
+	FileBase(not_null<Context*> context, DocumentData *doc);
 
 protected:
 	DocumentData *getShownDocument() const;
@@ -58,8 +59,8 @@ private:
 
 class Gif : public FileBase {
 public:
-	Gif(gsl::not_null<Context*> context, Result *result);
-	Gif(gsl::not_null<Context*> context, DocumentData *doc, bool hasDeleteButton);
+	Gif(not_null<Context*> context, Result *result);
+	Gif(not_null<Context*> context, DocumentData *doc, bool hasDeleteButton);
 
 	void setPosition(int32 position) override;
 	void initDimensions() override;
@@ -81,14 +82,12 @@ private:
 	QSize countFrameSize() const;
 
 	enum class StateFlag {
-		Over = 0x01,
-		DeleteOver = 0x02,
+		Over       = (1 << 0),
+		DeleteOver = (1 << 1),
 	};
-	Q_DECLARE_FLAGS(StateFlags, StateFlag);
+	using StateFlags = base::flags<StateFlag>;
+	friend inline constexpr auto is_flag_type(StateFlag) { return true; };
 	StateFlags _state;
-	friend inline StateFlags operator~(StateFlag flag) {
-		return ~StateFlags(flag);
-	}
 
 	Media::Clip::ReaderPointer _gif;
 	ClickHandlerPtr _delete;
@@ -117,9 +116,9 @@ private:
 
 class Photo : public ItemBase {
 public:
-	Photo(gsl::not_null<Context*> context, Result *result);
+	Photo(not_null<Context*> context, Result *result);
 	// Not used anywhere currently.
-	//Photo(gsl::not_null<Context*> context, PhotoData *photo);
+	//Photo(not_null<Context*> context, PhotoData *photo);
 
 	void initDimensions() override;
 
@@ -146,9 +145,9 @@ private:
 
 class Sticker : public FileBase {
 public:
-	Sticker(gsl::not_null<Context*> context, Result *result);
+	Sticker(not_null<Context*> context, Result *result);
 	// Not used anywhere currently.
-	//Sticker(gsl::not_null<Context*> context, DocumentData *document);
+	//Sticker(not_null<Context*> context, DocumentData *document);
 
 	void initDimensions() override;
 
@@ -180,7 +179,7 @@ private:
 
 class Video : public FileBase {
 public:
-	Video(gsl::not_null<Context*> context, Result *result);
+	Video(not_null<Context*> context, Result *result);
 
 	void initDimensions() override;
 
@@ -227,7 +226,7 @@ private:
 
 class File : public FileBase {
 public:
-	File(gsl::not_null<Context*> context, Result *result);
+	File(not_null<Context*> context, Result *result);
 
 	void initDimensions() override;
 
@@ -289,7 +288,7 @@ private:
 
 class Contact : public ItemBase {
 public:
-	Contact(gsl::not_null<Context*> context, Result *result);
+	Contact(not_null<Context*> context, Result *result);
 
 	void initDimensions() override;
 	int resizeGetHeight(int width) override;
@@ -307,7 +306,7 @@ private:
 
 class Article : public ItemBase {
 public:
-	Article(gsl::not_null<Context*> context, Result *result, bool withThumb);
+	Article(not_null<Context*> context, Result *result, bool withThumb);
 
 	void initDimensions() override;
 	int resizeGetHeight(int width) override;
@@ -330,7 +329,7 @@ private:
 
 class Game : public ItemBase {
 public:
-	Game(gsl::not_null<Context*> context, Result *result);
+	Game(not_null<Context*> context, Result *result);
 
 	void setPosition(int32 position) override;
 	void initDimensions() override;
