@@ -25,7 +25,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "core/file_utilities.h"
 #include "boxes/photo_crop_box.h"
 #include "boxes/confirm_box.h"
-#include "lang.h"
+#include "lang/lang_keys.h"
 #include "application.h"
 #include "ui/widgets/buttons.h"
 #include "ui/widgets/input_fields.h"
@@ -36,24 +36,38 @@ namespace Intro {
 
 SignupWidget::SignupWidget(QWidget *parent, Widget::Data *data) : Step(parent, data)
 , _photo(this, st::introPhotoSize, st::introPhotoIconPosition)
-, _first(this, st::introName, lang(lng_signup_firstname))
-, _last(this, st::introName, lang(lng_signup_lastname))
+, _first(this, st::introName, langFactory(lng_signup_firstname))
+, _last(this, st::introName, langFactory(lng_signup_lastname))
 , _invertOrder(langFirstNameGoesSecond())
 , _checkRequest(this) {
+	subscribe(Lang::Current().updated(), [this] { refreshLang(); });
+	if (_invertOrder) {
+		setTabOrder(_last, _first);
+	} else {
+		setTabOrder(_first, _last);
+	}
+
 	connect(_checkRequest, SIGNAL(timeout()), this, SLOT(onCheckRequest()));
 
 	setupPhotoButton();
 
-	if (_invertOrder) {
-		setTabOrder(_last, _first);
-	}
 	setErrorCentered(true);
 
-	setTitleText(lang(lng_signup_title));
-	setDescriptionText(lang(lng_signup_desc));
+	setTitleText(langFactory(lng_signup_title));
+	setDescriptionText(langFactory(lng_signup_desc));
 	setMouseTracking(true);
 }
 
+void SignupWidget::refreshLang() {
+	_invertOrder = langFirstNameGoesSecond();
+	if (_invertOrder) {
+		setTabOrder(_last, _first);
+	} else {
+		setTabOrder(_first, _last);
+	}
+	updateControlsGeometry();
+}
+
 void SignupWidget::setupPhotoButton() {
 	_photo->setClickedCallback(App::LambdaDelayed(st::defaultActiveButton.ripple.hideDuration, this, [this] {
 		auto imgExtensions = cImgExtensions();
@@ -71,7 +85,7 @@ void SignupWidget::setupPhotoButton() {
 			}
 
 			if (img.isNull() || img.width() > 10 * img.height() || img.height() > 10 * img.width()) {
-				showError(lang(lng_bad_photo));
+				showError(langFactory(lng_bad_photo));
 				return;
 			}
 			auto box = Ui::show(Box<PhotoCropBox>(img, PeerId(0)));
@@ -82,7 +96,10 @@ void SignupWidget::setupPhotoButton() {
 
 void SignupWidget::resizeEvent(QResizeEvent *e) {
 	Step::resizeEvent(e);
+	updateControlsGeometry();
+}
 
+void SignupWidget::updateControlsGeometry() {
 	auto photoRight = contentLeft() + st::introNextButton.width;
 	auto photoTop = contentTop() + st::introPhotoTop;
 	_photo->moveToLeft(photoRight - _photo->width(), photoTop);
@@ -144,7 +161,7 @@ void SignupWidget::nameSubmitDone(const MTPauth_Authorization &result) {
 	stopCheck();
 	auto &d = result.c_auth_authorization();
 	if (d.vuser.type() != mtpc_user || !d.vuser.c_user().is_self()) { // wtf?
-		showError(lang(lng_server_error));
+		showError(langFactory(lng_server_error));
 		return;
 	}
 	finish(d.vuser, _photoImage);
@@ -153,7 +170,7 @@ void SignupWidget::nameSubmitDone(const MTPauth_Authorization &result) {
 bool SignupWidget::nameSubmitFail(const RPCError &error) {
 	if (MTP::isFloodError(error)) {
 		stopCheck();
-		showError(lang(lng_flood_error));
+		showError(langFactory(lng_flood_error));
 		if (_invertOrder) {
 			_first->setFocus();
 		} else {
@@ -174,18 +191,19 @@ bool SignupWidget::nameSubmitFail(const RPCError &error) {
 		goBack();
 		return true;
 	} else if (err == "FIRSTNAME_INVALID") {
-		showError(lang(lng_bad_name));
+		showError(langFactory(lng_bad_name));
 		_first->setFocus();
 		return true;
 	} else if (err == "LASTNAME_INVALID") {
-		showError(lang(lng_bad_name));
+		showError(langFactory(lng_bad_name));
 		_last->setFocus();
 		return true;
 	}
 	if (cDebug()) { // internal server error
-		showError(err + ": " + error.description());
+		auto text = err + ": " + error.description();
+		showError([text] { return text; });
 	} else {
-		showError(lang(lng_server_error));
+		showError(langFactory(lng_server_error));
 	}
 	if (_invertOrder) {
 		_last->setFocus();
@@ -196,7 +214,7 @@ bool SignupWidget::nameSubmitFail(const RPCError &error) {
 }
 
 void SignupWidget::onInputChange() {
-	showError(QString());
+	hideError();
 }
 
 void SignupWidget::submit() {
@@ -219,7 +237,7 @@ void SignupWidget::submit() {
 		}
 	}
 
-	showError(QString());
+	hideError();
 
 	_firstName = _first->getLastText().trimmed();
 	_lastName = _last->getLastText().trimmed();
