@@ -35,7 +35,7 @@ namespace internal {
 
 class FFMpegReaderImplementation : public ReaderImplementation {
 public:
-	FFMpegReaderImplementation(FileLocation *location, QByteArray *data, uint64 playId);
+	FFMpegReaderImplementation(FileLocation *location, QByteArray *data, const AudioMsgId &audio);
 
 	ReadResult readFramesTill(TimeMs frameMs, TimeMs systemMs) override;
 
@@ -48,8 +48,6 @@ public:
 	bool hasAudio() const override {
 		return (_audioStreamId >= 0);
 	}
-	void pauseAudio() override;
-	void resumeAudio() override;
 
 	bool start(Mode mode, TimeMs &positionMs) override;
 	bool inspectAt(TimeMs &positionMs);
@@ -110,7 +108,7 @@ private:
 
 	bool _hasAudioStream = false;
 	int _audioStreamId = -1;
-	uint64 _playId = 0;
+	AudioMsgId _audioMsgId;
 	TimeMs _lastReadVideoMs = 0;
 	TimeMs _lastReadAudioMs = 0;
 
