@@ -323,7 +323,7 @@ void CoverWidget::handleSongChange() {
 	if (song->performer.isEmpty()) {
 		textWithEntities.text = song->title.isEmpty() ? (current.audio()->name.isEmpty() ? qsl("Unknown Track") : current.audio()->name) : song->title;
 	} else {
-		auto title = song->title.isEmpty() ? qsl("Unknown Track") : textClean(song->title);
+		auto title = song->title.isEmpty() ? qsl("Unknown Track") : TextUtilities::Clean(song->title);
 		textWithEntities.text = song->performer + QString::fromUtf8(" \xe2\x80\x93 ") + title;
 		textWithEntities.entities.append({ EntityInTextBold, 0, song->performer.size(), QString() });
 	}
