@@ -59,7 +59,7 @@ public:
 			finishDrag(false);
 		}
 	}
-	void ui_repaintHistoryItem(gsl::not_null<const HistoryItem*> item) {
+	void ui_repaintHistoryItem(not_null<const HistoryItem*> item) {
 		if (item == _item) {
 			repaintItem();
 		}
