@@ -33,7 +33,7 @@ public:
 	}
 
 private:
-	gsl::not_null<DcOptions*> _that;
+	not_null<DcOptions*> _that;
 	QWriteLocker _lock;
 
 };
@@ -247,13 +247,7 @@ QByteArray DcOptions::serialize() const {
 	auto result = QByteArray();
 	result.reserve(size);
 	{
-		QBuffer buffer(&result);
-		if (!buffer.open(QIODevice::WriteOnly)) {
-			LOG(("MTP Error: Can't open data for DcOptions::serialize()"));
-			return result;
-		}
-
-		QDataStream stream(&buffer);
+		QDataStream stream(&result, QIODevice::WriteOnly);
 		stream.setVersion(QDataStream::Qt_5_1);
 		stream << qint32(_data.size());
 		for (auto &item : _data) {
@@ -273,13 +267,7 @@ QByteArray DcOptions::serialize() const {
 }
 
 void DcOptions::constructFromSerialized(const QByteArray &serialized) {
-	auto readonly = serialized;
-	QBuffer buffer(&readonly);
-	if (!buffer.open(QIODevice::ReadOnly)) {
-		LOG(("MTP Error: Can't open data for DcOptions::constructFromSerialized()"));
-		return;
-	}
-	QDataStream stream(&buffer);
+	QDataStream stream(serialized);
 	stream.setVersion(QDataStream::Qt_5_1);
 	auto count = qint32(0);
 	stream >> count;
@@ -293,6 +281,14 @@ void DcOptions::constructFromSerialized(const QByteArray &serialized) {
 	for (auto i = 0; i != count; ++i) {
 		qint32 id = 0, flags = 0, port = 0, ipSize = 0;
 		stream >> id >> flags >> port >> ipSize;
+
+		// https://stackoverflow.com/questions/1076714/max-length-for-client-ip-address
+		constexpr auto kMaxIpSize = 45;
+		if (ipSize > kMaxIpSize) {
+			LOG(("MTP Error: Bad data inside DcOptions::constructFromSerialized()"));
+			return;
+		}
+
 		std::string ip(ipSize, ' ');
 		stream.readRawData(&ip[0], ipSize);
 
@@ -418,15 +414,15 @@ DcOptions::Variants DcOptions::lookup(DcId dcId, DcType type) const {
 				switch (protocol) {
 				case Variants::Tcp: return {
 					// Regular TCP IPv4
-					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_tcpo_only),
-					throughProxy ? qFlags(MTPDdcOption::Flag::f_static) : MTPDdcOption::Flags(0),
-					qFlags(MTPDdcOption::Flag::f_tcpo_only),
-					MTPDdcOption::Flags(0)
+					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | 0),
+					throughProxy ? (MTPDdcOption::Flag::f_static | 0) : MTPDdcOption::Flags(0),
+					(MTPDdcOption::Flag::f_tcpo_only | 0),
+					0
 				};
 				case Variants::Http: return {
 					// Regular HTTP IPv4
-					throughProxy ? qFlags(MTPDdcOption::Flag::f_static) : MTPDdcOption::Flags(0),
-					MTPDdcOption::Flags(0),
+					throughProxy ? (MTPDdcOption::Flag::f_static | 0) : MTPDdcOption::Flags(0),
+					0,
 				};
 				}
 			} break;
@@ -435,14 +431,14 @@ DcOptions::Variants DcOptions::lookup(DcId dcId, DcType type) const {
 				case Variants::Tcp: return {
 					// Regular TCP IPv6
 					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
-					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_ipv6),
+					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_ipv6 | 0),
 					(MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
-					qFlags(MTPDdcOption::Flag::f_ipv6),
+					(MTPDdcOption::Flag::f_ipv6 | 0),
 				};
 				case Variants::Http: return {
 					// Regular HTTP IPv6
-					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_ipv6),
-					qFlags(MTPDdcOption::Flag::f_ipv6),
+					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_ipv6 | 0),
+					(MTPDdcOption::Flag::f_ipv6 | 0),
 				};
 				}
 			} break;
@@ -455,20 +451,20 @@ DcOptions::Variants DcOptions::lookup(DcId dcId, DcType type) const {
 				case Variants::Tcp: return {
 					// Media download TCP IPv4
 					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only),
-					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_tcpo_only),
-					qFlags(MTPDdcOption::Flag::f_media_only),
-					throughProxy ? qFlags(MTPDdcOption::Flag::f_static) : MTPDdcOption::Flags(0),
+					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | 0),
+					(MTPDdcOption::Flag::f_media_only | 0),
+					throughProxy ? (MTPDdcOption::Flag::f_static | 0) : MTPDdcOption::Flags(0),
 					(MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only),
-					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_tcpo_only),
-					throughProxy ? qFlags(MTPDdcOption::Flag::f_tcpo_only) : qFlags(MTPDdcOption::Flag::f_media_only),
-					MTPDdcOption::Flags(0),
+					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | 0),
+					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | 0) : (MTPDdcOption::Flag::f_media_only | 0),
+					0,
 				};
 				case Variants::Http: return {
 					// Media download HTTP IPv4
-					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_media_only),
-					qFlags(MTPDdcOption::Flag::f_media_only),
-					throughProxy ? qFlags(MTPDdcOption::Flag::f_static) : MTPDdcOption::Flags(0),
-					MTPDdcOption::Flags(0),
+					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_media_only | 0),
+					(MTPDdcOption::Flag::f_media_only | 0),
+					throughProxy ? (MTPDdcOption::Flag::f_static | 0) : MTPDdcOption::Flags(0),
+					0,
 				};
 				}
 			} break;
@@ -479,18 +475,18 @@ DcOptions::Variants DcOptions::lookup(DcId dcId, DcType type) const {
 					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
 					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
 					(MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6),
-					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_ipv6),
+					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_ipv6 | 0),
 					(MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
 					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6),
 					throughProxy ? (MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_ipv6) : (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6),
-					qFlags(MTPDdcOption::Flag::f_ipv6)
+					(MTPDdcOption::Flag::f_ipv6 | 0)
 				};
 				case Variants::Http: return {
 					// Media download HTTP IPv6
 					throughProxy ? (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6),
 					(MTPDdcOption::Flag::f_media_only | MTPDdcOption::Flag::f_ipv6),
-					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_ipv6),
-					qFlags(MTPDdcOption::Flag::f_ipv6),
+					throughProxy ? (MTPDdcOption::Flag::f_ipv6 | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_ipv6 | 0),
+					(MTPDdcOption::Flag::f_ipv6 | 0),
 				};
 				}
 			} break;
@@ -503,14 +499,14 @@ DcOptions::Variants DcOptions::lookup(DcId dcId, DcType type) const {
 				case Variants::Tcp: return {
 					// CDN TCP IPv4
 					throughProxy ? (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_tcpo_only | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_tcpo_only),
-					throughProxy ? (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_cdn),
+					throughProxy ? (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_cdn | 0),
 					(MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_tcpo_only),
-					qFlags(MTPDdcOption::Flag::f_cdn),
+					(MTPDdcOption::Flag::f_cdn | 0),
 				};
 				case Variants::Http: return {
 					// CDN HTTP IPv4
-					throughProxy ? (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_static) : qFlags(MTPDdcOption::Flag::f_cdn),
-					qFlags(MTPDdcOption::Flag::f_cdn),
+					throughProxy ? (MTPDdcOption::Flag::f_cdn | MTPDdcOption::Flag::f_static) : (MTPDdcOption::Flag::f_cdn | 0),
+					(MTPDdcOption::Flag::f_cdn | 0),
 				};
 				}
 			} break;
