@@ -20,7 +20,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 */
 #pragma once
 
-#include "mtproto/core_types.h"
+#include "mtproto/type_utils.h"
 #include "mtproto/session.h"
 #include "core/single_timer.h"
 #include "mtproto/mtp_instance.h"
