@@ -55,15 +55,15 @@ OverviewInner::OverviewInner(OverviewWidget *overview, Ui::ScrollArea *scroll, P
 , _peer(peer->migrateTo() ? peer->migrateTo() : peer)
 , _type(type)
 , _reversed(_type != OverviewFiles && _type != OverviewLinks)
-, _migrated(_peer->migrateFrom() ? App::history(_peer->migrateFrom()->id) : 0)
-, _history(App::history(_peer->id))
+, _history(App::history(_peer))
+, _migrated(_history->migrateFrom())
 , _channel(peerToChannel(_peer->id))
 , _rowWidth(st::msgMinWidth)
 , _search(this, st::overviewFilter, langFactory(lng_dlg_filter))
 , _cancelSearch(this, st::dialogsCancelSearch)
 , _itemsToBeLoaded(LinksOverviewPerPage * 2)
 , _width(st::windowMinWidth) {
-	subscribe(AuthSession::Current().downloader().taskFinished(), [this] { update(); });
+	subscribe(Auth().downloader().taskFinished(), [this] { update(); });
 	subscribe(Global::RefItemRemoved(), [this](HistoryItem *item) {
 		itemRemoved(item);
 	});
@@ -96,6 +96,9 @@ OverviewInner::OverviewInner(OverviewWidget *overview, Ui::ScrollArea *scroll, P
 	subscribe(App::wnd()->dragFinished(), [this] {
 		dragActionUpdate(QCursor::pos());
 	});
+	subscribe(Auth().messageIdChanging, [this](std::pair<HistoryItem*, MsgId> update) {
+		changingMsgId(update.first, update.second);
+	});
 
 	if (_type == OverviewLinks || _type == OverviewFiles) {
 		_search->show();
@@ -177,7 +180,7 @@ MsgId OverviewInner::itemMsgId(MsgId msgId) const {
 }
 
 int32 OverviewInner::migratedIndexSkip() const {
-	return (_migrated && _history->overviewLoaded(_type)) ? _migrated->overview[_type].size() : 0;
+	return (_migrated && _history->overviewLoaded(_type)) ? _migrated->overview(_type).size() : 0;
 }
 
 void OverviewInner::fixItemIndex(int32 &current, MsgId msgId) const {
@@ -739,14 +742,14 @@ int32 OverviewInner::itemTop(const FullMsgId &msgId) const {
 void OverviewInner::preloadMore() {
 	if (_inSearch) {
 		if (!_searchRequest) {
-			MTPmessagesFilter filter = (_type == OverviewLinks) ? MTP_inputMessagesFilterUrl() : MTP_inputMessagesFilterDocument();
+			auto filter = (_type == OverviewLinks) ? MTP_inputMessagesFilterUrl() : MTP_inputMessagesFilterDocument();
 			if (!_searchFull) {
-				_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _history->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(_lastSearchId), MTP_int(SearchPerPage)), rpcDone(&OverviewInner::searchReceived, _lastSearchId ? SearchFromOffset : SearchFromStart), rpcFail(&OverviewInner::searchFailed, _lastSearchId ? SearchFromOffset : SearchFromStart));
+				_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _history->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(_lastSearchId), MTP_int(0), MTP_int(SearchPerPage), MTP_int(0), MTP_int(0)), rpcDone(&OverviewInner::searchReceived, _lastSearchId ? SearchFromOffset : SearchFromStart), rpcFail(&OverviewInner::searchFailed, _lastSearchId ? SearchFromOffset : SearchFromStart));
 				if (!_lastSearchId) {
 					_searchQueries.insert(_searchRequest, _searchQuery);
 				}
 			} else if (_migrated && !_searchFullMigrated) {
-				_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _migrated->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(_lastSearchMigratedId), MTP_int(SearchPerPage)), rpcDone(&OverviewInner::searchReceived, _lastSearchMigratedId ? SearchMigratedFromOffset : SearchMigratedFromStart), rpcFail(&OverviewInner::searchFailed, _lastSearchMigratedId ? SearchMigratedFromOffset : SearchMigratedFromStart));
+				_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _migrated->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(_lastSearchMigratedId), MTP_int(0), MTP_int(SearchPerPage), MTP_int(0), MTP_int(0)), rpcDone(&OverviewInner::searchReceived, _lastSearchMigratedId ? SearchMigratedFromOffset : SearchMigratedFromStart), rpcFail(&OverviewInner::searchFailed, _lastSearchMigratedId ? SearchMigratedFromOffset : SearchMigratedFromStart));
 			}
 		}
 	} else if (App::main()) {
@@ -759,7 +762,7 @@ void OverviewInner::preloadMore() {
 }
 
 bool OverviewInner::preloadLocal() {
-	if (_itemsToBeLoaded >= migratedIndexSkip() + _history->overview[_type].size()) return false;
+	if (_itemsToBeLoaded >= migratedIndexSkip() + _history->overview(_type).size()) return false;
 	_itemsToBeLoaded += LinksOverviewPerPage;
 	mediaOverviewUpdated();
 	return true;
@@ -797,7 +800,7 @@ void OverviewInner::paintEvent(QPaintEvent *e) {
 	auto ms = getms();
 	Overview::Layout::PaintContext context(ms, _selMode);
 
-	if (_history->overview[_type].isEmpty() && (!_migrated || !_history->overviewLoaded(_type) || _migrated->overview[_type].isEmpty())) {
+	if (_history->overview(_type).isEmpty() && (!_migrated || !_history->overviewLoaded(_type) || _migrated->overview(_type).isEmpty())) {
 		HistoryLayout::paintEmpty(p, _width, height());
 		return;
 	} else if (_inSearch && _searchResults.isEmpty() && _searchFull && (!_migrated || _searchFullMigrated) && !_searchTimer.isActive()) {
@@ -1482,7 +1485,7 @@ bool OverviewInner::onSearchMessages(bool searchCache) {
 		_searchQuery = q;
 		_searchFull = _searchFullMigrated = false;
 		auto filter = (_type == OverviewLinks) ? MTP_inputMessagesFilterUrl() : MTP_inputMessagesFilterDocument();
-		_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _history->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(SearchPerPage)), rpcDone(&OverviewInner::searchReceived, SearchFromStart), rpcFail(&OverviewInner::searchFailed, SearchFromStart));
+		_searchRequest = MTP::send(MTPmessages_Search(MTP_flags(0), _history->peer->input, MTP_string(_searchQuery), MTP_inputUserEmpty(), filter, MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(0), MTP_int(SearchPerPage), MTP_int(0), MTP_int(0)), rpcDone(&OverviewInner::searchReceived, SearchFromStart), rpcFail(&OverviewInner::searchFailed, SearchFromStart));
 		_searchQueries.insert(_searchRequest, _searchQuery);
 	}
 	return false;
@@ -1622,17 +1625,28 @@ void OverviewInner::onTouchScrollTimer() {
 
 void OverviewInner::mediaOverviewUpdated() {
 	if (_type == OverviewPhotos || _type == OverviewVideos) {
-		History::MediaOverview &o(_history->overview[_type]), *migratedOverview = _migrated ? &_migrated->overview[_type] : 0;
-		int32 migrateCount = migratedIndexSkip();
-		int32 wasCount = _items.size(), fullCount = (migrateCount + o.size());
-		int32 tocheck = qMin(fullCount, _itemsToBeLoaded);
+		auto &o = _history->overview(_type);
+		auto migratedOverview = _migrated ? &_migrated->overview(_type) : nullptr;
+		auto migrateCount = migratedIndexSkip();
+		auto wasCount = _items.size();
+		auto fullCount = (migrateCount + o.size());
+		auto tocheck = qMin(fullCount, _itemsToBeLoaded);
 		_items.reserve(tocheck);
 
-		int32 index = 0;
-		bool allGood = true;
-		for (int32 i = fullCount, l = fullCount - tocheck; i > l;) {
+		auto index = 0;
+		auto allGood = true;
+		auto migrateIt = migratedOverview ? migratedOverview->end() : o.end();
+		auto it = o.end();
+		for (auto i = fullCount, l = fullCount - tocheck; i > l;) {
 			--i;
-			MsgId msgid = ((i < migrateCount) ? -migratedOverview->at(i) : o.at(i - migrateCount));
+			auto msgid = MsgId(0);
+			if (i < migrateCount) {
+				--migrateIt;
+				msgid = -(*migrateIt);
+			} else {
+				--it;
+				msgid = *it;
+			}
 			if (allGood) {
 				if (_items.size() > index && complexMsgId(_items.at(index)->getItem()) == msgid) {
 					++index;
@@ -1654,54 +1668,70 @@ void OverviewInner::mediaOverviewUpdated() {
 		bool dateEveryMonth = (_type == OverviewFiles), dateEveryDay = (_type == OverviewLinks);
 		bool withDates = (dateEveryMonth || dateEveryDay);
 
-		History::MediaOverview &o(_history->overview[_type]), *migratedOverview = _migrated ? &_migrated->overview[_type] : 0;
-		int32 migrateCount = migratedIndexSkip();
-		int32 l = _inSearch ? _searchResults.size() : (migrateCount + o.size()), tocheck = qMin(l, _itemsToBeLoaded);
+		auto &o = _history->overview(_type);
+		auto migratedOverview = _migrated ? &_migrated->overview(_type) : nullptr;
+		auto migrateCount = migratedIndexSkip();
+		auto l = _inSearch ? _searchResults.size() : (migrateCount + o.size());
+		auto tocheck = qMin(l, _itemsToBeLoaded);
 		_items.reserve((withDates ? 2 : 1) * tocheck); // day items
 
-		int32 top = 0, index = 0;
+		auto migrateIt = migratedOverview ? migratedOverview->end() : o.end();
+		auto it = o.end();
+
+		auto top = 0;
+		auto count = 0;
 		bool allGood = true;
 		QDate prevDate;
-		for (int32 i = 0; i < tocheck; ++i) {
-			MsgId msgid = _inSearch ? _searchResults.at(l - i - 1) : ((l - i - 1 < migrateCount) ? -migratedOverview->at(l - i - 1) : o.at(l - i - 1 - migrateCount));
+		for (auto i = 0; i < tocheck; ++i) {
+			auto msgid = MsgId(0);
+			auto index = l - i - 1;
+			if (_inSearch) {
+				msgid = _searchResults[index];
+			} else if (index < migrateCount) {
+				--migrateIt;
+				msgid = -(*migrateIt);
+			} else {
+				--it;
+				msgid = *it;
+			}
 			if (allGood) {
-				if (_items.size() > index && complexMsgId(_items.at(index)->getItem()) == msgid) {
-					if (withDates) prevDate = _items.at(index)->getItem()->date.date();
-					top = _items.at(index)->Get<Overview::Layout::Info>()->top;
+				if (_items.size() > count && complexMsgId(_items.at(count)->getItem()) == msgid) {
+					if (withDates) prevDate = _items.at(count)->getItem()->date.date();
+					top = _items.at(count)->Get<Overview::Layout::Info>()->top;
 					if (!_reversed) {
-						top += _items.at(index)->height();
+						top += _items.at(count)->height();
 					}
-					++index;
+					++count;
 					continue;
 				}
-				if (_items.size() > index + 1 && !_items.at(index)->toMediaItem() && complexMsgId(_items.at(index + 1)->getItem()) == msgid) { // day item
-					++index;
-					if (withDates) prevDate = _items.at(index)->getItem()->date.date();
-					top = _items.at(index)->Get<Overview::Layout::Info>()->top;
+				if (_items.size() > count + 1 && !_items.at(count)->toMediaItem() && complexMsgId(_items.at(count + 1)->getItem()) == msgid) { // day item
+					++count;
+					if (withDates) prevDate = _items.at(count)->getItem()->date.date();
+					top = _items.at(count)->Get<Overview::Layout::Info>()->top;
 					if (!_reversed) {
-						top += _items.at(index)->height();
+						top += _items.at(count)->height();
 					}
-					++index;
+					++count;
 					continue;
 				}
 				allGood = false;
 			}
-			HistoryItem *item = App::histItemById(itemChannel(msgid), itemMsgId(msgid));
+			auto item = App::histItemById(itemChannel(msgid), itemMsgId(msgid));
 			auto layout = layoutPrepare(item);
 			if (!layout) continue;
 
 			if (withDates) {
 				QDate date = item->date.date();
-				if (!index || (index > 0 && (dateEveryMonth ? (date.month() != prevDate.month() || date.year() != prevDate.year()) : (date != prevDate)))) {
-					top += setLayoutItem(index, layoutPrepare(date, dateEveryMonth), top);
-					++index;
+				if (!count || (count > 0 && (dateEveryMonth ? (date.month() != prevDate.month() || date.year() != prevDate.year()) : (date != prevDate)))) {
+					top += setLayoutItem(count, layoutPrepare(date, dateEveryMonth), top);
+					++count;
 					prevDate = date;
 				}
 			}
-			top += setLayoutItem(index, layout, top);
-			++index;
+			top += setLayoutItem(count, layout, top);
+			++count;
 		}
-		if (_items.size() > index) _items.resize(index);
+		if (_items.size() > count) _items.resize(count);
 
 		_height = top;
 	}
@@ -1725,6 +1755,10 @@ void OverviewInner::mediaOverviewUpdated() {
 }
 
 void OverviewInner::changingMsgId(HistoryItem *row, MsgId newId) {
+	if (peer() != row->history()->peer && migratePeer() != row->history()->peer) {
+		return;
+	}
+
 	MsgId oldId = complexMsgId(row);
 	if (row->history() == _migrated) newId = -newId;
 
@@ -1916,7 +1950,7 @@ OverviewInner::~OverviewInner() {
 	clear();
 }
 
-OverviewWidget::OverviewWidget(QWidget *parent, gsl::not_null<Window::Controller*> controller, PeerData *peer, MediaOverviewType type) : Window::AbstractSectionWidget(parent, controller)
+OverviewWidget::OverviewWidget(QWidget *parent, not_null<Window::Controller*> controller, PeerData *peer, MediaOverviewType type) : Window::AbstractSectionWidget(parent, controller)
 , _topBar(this, controller)
 , _scroll(this, st::settingsScroll, false)
 , _mediaType(this, st::defaultDropdownMenu)
@@ -1946,7 +1980,7 @@ void OverviewWidget::clear() {
 }
 
 void OverviewWidget::onScroll() {
-	AuthSession::Current().downloader().clearPriorities();
+	Auth().downloader().clearPriorities();
 	int32 preloadThreshold = _scroll->height() * 5;
 	bool needToPreload = false;
 	do {
@@ -2207,9 +2241,9 @@ void OverviewWidget::mediaOverviewUpdated(const Notify::PeerUpdate &update) {
 	History *m = (update.peer && update.peer->migrateFrom()) ? App::historyLoaded(update.peer->migrateFrom()->id) : 0;
 	if (h) {
 		for (int32 i = 0; i < OverviewCount; ++i) {
-			if (!h->overview[i].isEmpty() || h->overviewCount(i) > 0 || i == type()) {
+			if (!h->overview(i).isEmpty() || h->overviewCount(i) > 0 || i == type()) {
 				mask |= (1 << i);
-			} else if (m && (!m->overview[i].isEmpty() || m->overviewCount(i) > 0)) {
+			} else if (m && (!m->overview(i).isEmpty() || m->overviewCount(i) > 0)) {
 				mask |= (1 << i);
 			}
 		}
@@ -2245,12 +2279,6 @@ void OverviewWidget::mediaOverviewUpdated(const Notify::PeerUpdate &update) {
 	}
 }
 
-void OverviewWidget::changingMsgId(HistoryItem *row, MsgId newId) {
-	if (peer() == row->history()->peer || migratePeer() == row->history()->peer) {
-		_inner->changingMsgId(row, newId);
-	}
-}
-
 void OverviewWidget::grapWithoutTopBarShadow() {
 	grabStart();
 	_topShadow->hide();
@@ -2262,7 +2290,7 @@ void OverviewWidget::grabFinish() {
 	_topShadow->show();
 }
 
-void OverviewWidget::ui_repaintHistoryItem(gsl::not_null<const HistoryItem*> item) {
+void OverviewWidget::ui_repaintHistoryItem(not_null<const HistoryItem*> item) {
 	if (peer() == item->history()->peer || migratePeer() == item->history()->peer) {
 		_inner->repaintItem(item);
 	}
