@@ -44,12 +44,12 @@ bool load(QLibrary &lib, const char *name, Function &func) {
 		return false;
 	}
 
-    func = reinterpret_cast<Function>(lib.resolve(name));
-    if (func) {
-        return true;
-    }
+	func = reinterpret_cast<Function>(lib.resolve(name));
+	if (func) {
+		return true;
+	}
 	LOG(("Error: failed to load '%1' function!").arg(name));
-    return false;
+	return false;
 }
 
 typedef gboolean (*f_gtk_init_check)(int *argc, char ***argv);
@@ -112,13 +112,13 @@ extern f_gtk_file_chooser_dialog_new gtk_file_chooser_dialog_new;
 typedef gboolean (*f_gtk_file_chooser_set_current_folder)(GtkFileChooser *chooser, const gchar *filename);
 extern f_gtk_file_chooser_set_current_folder gtk_file_chooser_set_current_folder;
 
-typedef gchar *(*f_gtk_file_chooser_get_current_folder)(GtkFileChooser *chooser);
+typedef gchar* (*f_gtk_file_chooser_get_current_folder)(GtkFileChooser *chooser);
 extern f_gtk_file_chooser_get_current_folder gtk_file_chooser_get_current_folder;
 
 typedef void (*f_gtk_file_chooser_set_current_name)(GtkFileChooser *chooser, const gchar *name);
 extern f_gtk_file_chooser_set_current_name gtk_file_chooser_set_current_name;
 
-typedef gboolean (*f_gtk_file_chooser_select_filename)(GtkFileChooser *chooser, const char *filename);
+typedef gboolean (*f_gtk_file_chooser_select_filename)(GtkFileChooser *chooser, const gchar *filename);
 extern f_gtk_file_chooser_select_filename gtk_file_chooser_select_filename;
 
 typedef GSList* (*f_gtk_file_chooser_get_filenames)(GtkFileChooser *chooser);
@@ -163,9 +163,27 @@ extern f_gtk_file_filter_add_pattern gtk_file_filter_add_pattern;
 typedef void (*f_gtk_file_chooser_add_filter)(GtkFileChooser *chooser, GtkFileFilter *filter);
 extern f_gtk_file_chooser_add_filter gtk_file_chooser_add_filter;
 
+typedef void (*f_gtk_file_chooser_set_preview_widget)(GtkFileChooser *chooser, GtkWidget *preview_widget);
+extern f_gtk_file_chooser_set_preview_widget gtk_file_chooser_set_preview_widget;
+
+typedef gchar* (*f_gtk_file_chooser_get_preview_filename)(GtkFileChooser *chooser);
+extern f_gtk_file_chooser_get_preview_filename gtk_file_chooser_get_preview_filename;
+
+typedef void (*f_gtk_file_chooser_set_preview_widget_active)(GtkFileChooser *chooser, gboolean active);
+extern f_gtk_file_chooser_set_preview_widget_active gtk_file_chooser_set_preview_widget_active;
+
 typedef GtkFileFilter* (*f_gtk_file_filter_new)(void);
 extern f_gtk_file_filter_new gtk_file_filter_new;
 
+typedef GtkWidget* (*f_gtk_image_new)(void);
+extern f_gtk_image_new gtk_image_new;
+
+typedef void (*f_gtk_image_set_from_pixbuf)(GtkImage *image, GdkPixbuf *pixbuf);
+extern f_gtk_image_set_from_pixbuf gtk_image_set_from_pixbuf;
+
+typedef void (*f_gdk_set_allowed_backends)(const gchar *backends);
+extern f_gdk_set_allowed_backends gdk_set_allowed_backends;
+
 typedef void (*f_gdk_window_set_modal_hint)(GdkWindow *window, gboolean modal);
 extern f_gdk_window_set_modal_hint gdk_window_set_modal_hint;
 
@@ -211,6 +229,14 @@ inline GtkFileChooser *gtk_file_chooser_cast(Object *obj) {
 	return g_type_cic_helper<GtkFileChooser, Object>(obj, gtk_file_chooser_get_type());
 }
 
+typedef GType (*f_gtk_image_get_type)(void) G_GNUC_CONST;
+extern f_gtk_image_get_type gtk_image_get_type;
+
+template <typename Object>
+inline GtkImage *gtk_image_cast(Object *obj) {
+	return g_type_cic_helper<GtkImage, Object>(obj, gtk_image_get_type());
+}
+
 typedef GType (*f_gtk_button_get_type)(void) G_GNUC_CONST;
 extern f_gtk_button_get_type gtk_button_get_type;
 
@@ -279,6 +305,9 @@ extern f_gdk_pixbuf_new_from_data gdk_pixbuf_new_from_data;
 typedef GdkPixbuf* (*f_gdk_pixbuf_new_from_file)(const gchar *filename, GError **error);
 extern f_gdk_pixbuf_new_from_file gdk_pixbuf_new_from_file;
 
+typedef GdkPixbuf* (*f_gdk_pixbuf_new_from_file_at_size)(const gchar *filename, int width, int height, GError **error);
+extern f_gdk_pixbuf_new_from_file_at_size gdk_pixbuf_new_from_file_at_size;
+
 typedef GtkStatusIcon* (*f_gtk_status_icon_new_from_pixbuf)(GdkPixbuf *pixbuf);
 extern f_gtk_status_icon_new_from_pixbuf gtk_status_icon_new_from_pixbuf;
 
