@@ -26,7 +26,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "storage/localstorage.h"
 #include "window/notifications_manager_default.h"
 #include "platform/platform_notifications_manager.h"
-#include "boxes/contacts_box.h"
+#include "boxes/peer_list_controllers.h"
 #include "boxes/about_box.h"
 #include "lang/lang_keys.h"
 #include "platform/mac/mac_utilities.h"
@@ -407,10 +407,10 @@ void MainWindow::psFirstShow() {
 void MainWindow::createGlobalMenu() {
 	auto main = psMainMenu.addMenu(qsl("Telegram"));
 	auto about = main->addAction(lng_mac_menu_about_telegram(lt_telegram, qsl("Telegram")));
-	connect(about, SIGNAL(triggered()), base::lambda_slot(about, [] {
+	connect(about, &QAction::triggered, about, [] {
 		if (App::wnd() && App::wnd()->isHidden()) App::wnd()->showFromTray();
 		Ui::show(Box<AboutBox>());
-	}), SLOT(action()));
+	});
 	about->setMenuRole(QAction::AboutQtRole);
 
 	main->addSeparator();
@@ -433,12 +433,15 @@ void MainWindow::createGlobalMenu() {
 
 	QMenu *window = psMainMenu.addMenu(lang(lng_mac_menu_window));
 	psContacts = window->addAction(lang(lng_mac_menu_contacts));
-	connect(psContacts, SIGNAL(triggered()), base::lambda_slot(psContacts, [] {
+	connect(psContacts, &QAction::triggered, psContacts, [] {
 		if (App::wnd() && App::wnd()->isHidden()) App::wnd()->showFromTray();
 
 		if (!App::self()) return;
-		Ui::show(Box<ContactsBox>());
-	}), SLOT(action()));
+		Ui::show(Box<PeerListBox>(std::make_unique<ContactsBoxController>(), [](not_null<PeerListBox*> box) {
+			box->addButton(langFactory(lng_close), [box] { box->closeBox(); });
+			box->addLeftButton(langFactory(lng_profile_add_contact), [] { App::wnd()->onShowAddContact(); });
+		}));
+	});
 	psAddContact = window->addAction(lang(lng_mac_menu_add_contact), App::wnd(), SLOT(onShowAddContact()));
 	window->addSeparator();
 	psNewGroup = window->addAction(lang(lng_mac_menu_new_group), App::wnd(), SLOT(onShowNewGroup()));
