@@ -46,8 +46,6 @@ double objc_appkitVersion();
 QString objc_documentsPath();
 QString objc_appDataPath();
 QString objc_downloadPath();
-QString objc_currentCountry();
-QString objc_currentLang();
 QByteArray objc_downloadPathBookmark(const QString &path);
 QByteArray objc_pathBookmark(const QString &path);
 void objc_downloadPathEnableAccess(const QByteArray &bookmark);
