@@ -659,7 +659,7 @@ int32 MainWindow::screenNameChecksum(const QString &name) const {
 
 void MainWindow::psRefreshTaskbarIcon() {
 	auto refresher = object_ptr<QWidget>(this);
-	auto guard = base::scope_guard([&refresher] {
+	auto guard = gsl::finally([&refresher] {
 		refresher.destroy();
 	});
 	refresher->setWindowFlags(static_cast<Qt::WindowFlags>(Qt::Tool) | Qt::FramelessWindowHint);
