@@ -43,6 +43,8 @@ inline void DeInitOnTopPanel(QWidget *panel) {
 inline void ReInitOnTopPanel(QWidget *panel) {
 }
 
+QString CurrentExecutablePath(int argc, char *argv[]);
+
 namespace ThirdParty {
 
 inline void start() {
@@ -78,8 +80,6 @@ QString psLocalServerPrefix();
 QString psAppDataPath();
 QString psAppDataPathOld();
 QString psDownloadPath();
-QString psCurrentExeDirectory(int argc, char *argv[]);
-QString psCurrentExeName(int argc, char *argv[]);
 void psAutoStart(bool start, bool silent = false);
 void psSendToMenu(bool send, bool silent = false);
 
