@@ -20,7 +20,7 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 */
 #pragma once
 
-#include "core/variant.h"
+#include "base/variant.h"
 
 enum class CompressConfirm {
 	Auto,
