@@ -26,7 +26,7 @@ namespace Ui {
 
 class CrossAnimation {
 public:
-	static void paint(Painter &p, const style::CrossAnimation &st, style::color color, int x, int y, int outerWidth, float64 shown);
+	static void paint(Painter &p, const style::CrossAnimation &st, style::color color, int x, int y, int outerWidth, float64 shown, float64 loading = 0.);
 
 };
 
