@@ -78,11 +78,11 @@ void colorizeImage(const QImage &src, QColor c, QImage *outResult, QRect srcRect
 	if (srcRect.isNull()) {
 		srcRect = src.rect();
 	} else {
-		t_assert(src.rect().contains(srcRect));
+		Assert(src.rect().contains(srcRect));
 	}
 	auto width = srcRect.width();
 	auto height = srcRect.height();
-	t_assert(outResult && outResult->rect().contains(QRect(dstPoint, srcRect.size())));
+	Assert(outResult && outResult->rect().contains(QRect(dstPoint, srcRect.size())));
 
 	auto pattern = anim::shifted(c);
 
@@ -91,16 +91,16 @@ void colorizeImage(const QImage &src, QColor c, QImage *outResult, QRect srcRect
 	auto resultIntsPerLine = (outResult->bytesPerLine() >> 2);
 	auto resultIntsAdded = resultIntsPerLine - width * resultIntsPerPixel;
 	auto resultInts = reinterpret_cast<uint32*>(outResult->bits()) + dstPoint.y() * resultIntsPerLine + dstPoint.x() * resultIntsPerPixel;
-	t_assert(resultIntsAdded >= 0);
-	t_assert(outResult->depth() == static_cast<int>((resultIntsPerPixel * sizeof(uint32)) << 3));
-	t_assert(outResult->bytesPerLine() == (resultIntsPerLine << 2));
+	Assert(resultIntsAdded >= 0);
+	Assert(outResult->depth() == static_cast<int>((resultIntsPerPixel * sizeof(uint32)) << 3));
+	Assert(outResult->bytesPerLine() == (resultIntsPerLine << 2));
 
 	auto maskBytesPerPixel = (src.depth() >> 3);
 	auto maskBytesPerLine = src.bytesPerLine();
 	auto maskBytesAdded = maskBytesPerLine - width * maskBytesPerPixel;
 	auto maskBytes = src.constBits() + srcRect.y() * maskBytesPerLine + srcRect.x() * maskBytesPerPixel;
-	t_assert(maskBytesAdded >= 0);
-	t_assert(src.depth() == (maskBytesPerPixel << 3));
+	Assert(maskBytesAdded >= 0);
+	Assert(src.depth() == (maskBytesPerPixel << 3));
 	for (int y = 0; y != height; ++y) {
 		for (int x = 0; x != width; ++x) {
 			auto maskOpacity = static_cast<anim::ShiftedMultiplier>(*maskBytes) + 1;
