@@ -18,20 +18,20 @@ Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
 #include "ui/widgets/dropdown_menu.h"
 
 #include "application.h"
-#include "lang.h"
+#include "lang/lang_keys.h"
 
 namespace Ui {
 
 DropdownMenu::DropdownMenu(QWidget *parent, const style::DropdownMenu &st) : InnerDropdown(parent, st.wrap)
-, _st(st)
-, _menu(this, _st.menu) {
+, _st(st) {
+	_menu = setOwnedWidget(object_ptr<Ui::Menu>(this, _st.menu));
 	init();
 }
 
 // Not ready with submenus yet.
 //DropdownMenu::DropdownMenu(QWidget *parent, QMenu *menu, const style::DropdownMenu &st) : InnerDropdown(parent, st.wrap)
-//, _st(st)
-//, _menu(this, menu, _st.menu) {
+//, _st(st) {
+//	_menu = setOwnedWidget(object_ptr<Ui::Menu>(this, menu, _st.menu));
 //	init();
 //
 //	for (auto action : actions()) {
@@ -45,8 +45,6 @@ DropdownMenu::DropdownMenu(QWidget *parent, const style::DropdownMenu &st) : Inn
 void DropdownMenu::init() {
 	InnerDropdown::setHiddenCallback([this] { hideFinish(); });
 
-	setOwnedWidget(_menu);
-
 	_menu->setResizedCallback([this] { resizeToContent(); });
 	_menu->setActivatedCallback([this](QAction *action, int actionTop, TriggeredSource source) {
 		handleActivated(action, actionTop, source);
