@@ -45,7 +45,7 @@ public:
 
 private:
 	struct Line {
-		Line(Part was, Part now) : was(std_::move(was)), now(std_::move(now)) {
+		Line(Part was, Part now) : was(std::move(was)), now(std::move(now)) {
 		}
 		Part was;
 		Part now;
@@ -112,7 +112,7 @@ public:
 	void clickHandlerActiveChanged(const ClickHandlerPtr &action, bool active) override;
 	void clickHandlerPressedChanged(const ClickHandlerPtr &action, bool pressed) override;
 
-	static std_::unique_ptr<CrossFadeAnimation> CrossFade(FlatLabel *from, FlatLabel *to, style::color bg, QPoint fromPosition = QPoint(), QPoint toPosition = QPoint());
+	static std::unique_ptr<CrossFadeAnimation> CrossFade(FlatLabel *from, FlatLabel *to, style::color bg, QPoint fromPosition = QPoint(), QPoint toPosition = QPoint());
 
 protected:
 	void paintEvent(QPaintEvent *e) override;
