@@ -436,7 +436,7 @@ bool Editor::Inner::readData() {
 		if (!_existingRows->feedDescription(name, description)) {
 			if (row.value.data()[0] == '#') {
 				auto result = readColor(name, row.value.data() + 1, row.value.size() - 1);
-				t_assert(!result.error);
+				Assert(!result.error);
 				_newRows->feed(name, result.color);
 				//if (!_newRows->feedFallbackName(name, str_const_toString(row.fallback))) {
 				//	Unexpected("Row for fallback not found");
@@ -448,7 +448,7 @@ bool Editor::Inner::readData() {
 				} else if (!_newRows->feedCopy(name, copyOf)) {
 					Unexpected("Copy of unknown value in the default palette");
 				}
-				t_assert(row.fallback.size() == 0);
+				Assert(row.fallback.size() == 0);
 			}
 			if (!_newRows->feedDescription(name, description)) {
 				Unexpected("Row for description not found");
