@@ -31,7 +31,10 @@ struct CurrentData {
 	bool backgroundTiled = false;
 };
 
-std_::unique_ptr<Preview> GeneratePreview(const QString &filepath, const CurrentData &data);
+std::unique_ptr<Preview> GeneratePreview(const QString &filepath, const CurrentData &data);
+
+int DefaultPreviewTitleHeight();
+void DefaultPreviewWindowFramePaint(QImage &preview, const style::palette &palette, QRect body, int outerWidth);
 
 } // namespace Theme
 } // namespace Window
